@@ -107,17 +107,15 @@ static void *my_malloc(size_t size)
 
 static void my_free(_ptr)
 {
-
-GB.Free((void **)&_ptr);
+	GB.Free(POINTER(&_ptr));
 }
 
 #define malloc(_size) my_malloc(_size)
-
-//#define free(_ptr) GB.Free((void **)&_ptr)
 #define free(_ptr) my_free(_ptr)
 
 
-static void quote(char *data, long len, DB_FORMAT_CALLBACK add)
+#if 0
+static void quote(char *data, int len, DB_FORMAT_CALLBACK add)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -142,10 +140,11 @@ fflush(stderr);
 	}
 	(*add)("'", 1);
 }
+#endif
 
 /* internal function to quote a value stored as a blob */
 
-static void quote_blob(char *data, long len, DB_FORMAT_CALLBACK add)
+static void quote_blob(char *data, int len, DB_FORMAT_CALLBACK add)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -180,7 +179,8 @@ fflush(stderr);
 
 /* internal function to unquote a value stored as a string */
 
-static int unquote(char *data, long len, DB_FORMAT_CALLBACK add)
+#if 0
+static int unquote(char *data, int len, DB_FORMAT_CALLBACK add)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -206,10 +206,11 @@ fflush(stderr);
 
 	return FALSE;
 }
+#endif
 
 /* internal function to unquote a value stored as a blob */
 
-static int unquote_blob(char *data, long len, DB_FORMAT_CALLBACK add)
+static int unquote_blob(char *data, int len, DB_FORMAT_CALLBACK add)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -311,7 +312,7 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, int type)
 	GB_VALUE conv;
 	GB_DATE_SERIAL date;
 	double sec;
-	long len;
+	int len;
 	int bc = 0;
 
 	switch (type)
@@ -489,7 +490,7 @@ fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
 fprintf(stderr,"\topen_database\n");
 fflush(stderr);
 #endif
-	//long V_OD_erg;
+	//int V_OD_erg;
 	SQLRETURN retcode;
 	ODBC_CONN *odbc;
 
@@ -906,7 +907,7 @@ fflush(stderr);
 #endif
 	SQLCHAR colname[32];
 	SQLSMALLINT colnamelen;
-	SQLUINTEGER precision;
+	SQLULEN precision;
 	SQLSMALLINT scale;
 	SQLINTEGER i;
 	SQLINTEGER displaysize;
@@ -914,7 +915,7 @@ fflush(stderr);
 	ODBC_FIELDS *field, *current;
 	SQLINTEGER collen;
 	int nresultcols;
-	//long V_OD_erg=0;
+	//int V_OD_erg=0;
 	SQLRETURN retcode;
 
 
@@ -1013,10 +1014,10 @@ fflush(stderr);
 static void query_init(DB_RESULT result, DB_INFO * info, int *count)
 {
 
-	//long V_OD_erg=0;
+	//int V_OD_erg=0;
 	SQLRETURN retcode;
 	ODBC_RESULT *res = (ODBC_RESULT *) result;
-	SQLINTEGER rowsNum=0;
+	SQLLEN rowsNum=0;
 	SQLSMALLINT colsNum=0;
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -1116,8 +1117,8 @@ static int query_fill(DB_DATABASE *db, DB_RESULT result, int pos, GB_VARIANT_VAL
 	ODBC_FIELDS *current;
 	SQLRETURN retcode;
 	int nresultcols;
-	long displaysize;
-	//long V_OD_erg=0;
+	int displaysize;
+	//int V_OD_erg=0;
 	
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -1182,10 +1183,10 @@ fflush(stderr);
 		{
 			displaysize=0;
 			char * fieldata;
-			SQLUINTEGER   precision=0;
+			SQLULEN   precision=0;
 			
 			SQLSMALLINT colnamelen=0,scale=0,type;
-			SQLINTEGER read=0;
+			SQLLEN read=0;
 			SQLCHAR namebuff[25];
 				
 			SQLDescribeCol(res->odbcStatHandle, i+1 , namebuff, sizeof(namebuff), &colnamelen,&type,&precision, &scale,NULL);
@@ -1273,14 +1274,14 @@ static void blob_read(DB_RESULT result, int pos, int field, DB_BLOB *blob)
 
 
 int i;
-//long outlen;
-//long precision;
-//long scale;
-//long displaysize;
+//int outlen;
+//int precision;
+//int scale;
+//int displaysize;
 //char * pointer;
 ODBC_RESULT * res= (ODBC_RESULT *) result;
 ODBC_FIELDS * cfield ;
-SQLINTEGER strlen;
+SQLLEN strlen;
 SQLRETURN retcode;
 i=0;
 cfield=res->fields;
@@ -1320,7 +1321,7 @@ fflush(stderr);
 		
 
 	char *data;
-	long len;
+	int len;
 
   	if (!unquote_blob(blob->data, blob->length, DB.Query.AddLength))
   	{
@@ -1358,7 +1359,7 @@ fflush(stderr);
 	SQLCHAR colname[32];
 	SQLSMALLINT coltype=0;
 	SQLSMALLINT colnamelen=0;
-	SQLUINTEGER precision=0;
+	SQLULEN precision=0;
 	SQLSMALLINT scale=0;
 	
 	ODBC_RESULT *res = (ODBC_RESULT *) result;
@@ -1393,7 +1394,7 @@ fflush(stderr);
 	SQLCHAR colname[32];
 	SQLSMALLINT coltype;
 	SQLSMALLINT colnamelen;
-	SQLUINTEGER precision;
+	SQLULEN precision;
 	SQLSMALLINT scale;
 	SQLSMALLINT colsNum;
 	int field;
@@ -1441,7 +1442,7 @@ fflush(stderr);
 	SQLCHAR colname[32];
 	SQLSMALLINT coltype;
 	SQLSMALLINT colnamelen;
-	SQLUINTEGER precision;
+	SQLULEN precision;
 	SQLSMALLINT scale;
 	ODBC_RESULT *res = (ODBC_RESULT *) result;
 	SQLRETURN retcode;
@@ -1476,7 +1477,7 @@ fflush(stderr);
 	SQLCHAR colname[32];
 	SQLSMALLINT coltype;
 	SQLSMALLINT colnamelen;
-	SQLUINTEGER precision;
+	SQLULEN precision;
 	SQLSMALLINT scale;
 	ODBC_RESULT *res = (ODBC_RESULT *) result;
 
@@ -1630,7 +1631,7 @@ fflush(stderr);
 	}
 
 	info->nfield = colsNum;
-	GB.Alloc((void **) &info->field, sizeof(DB_FIELD) * colsNum);
+	GB.Alloc(POINTER(&info->field), sizeof(DB_FIELD) * colsNum);
 	i = 0;
 	current = fieldstr;
 
@@ -1800,7 +1801,7 @@ retcode=SQLNumResultCols(statHandle2, &colsNum);
 
 
 
-	GB.Alloc((void **) &info->index, sizeof(int) * i);
+	GB.Alloc(POINTER(&info->index), sizeof(int) * i);
 	info->nindex = i;
 
 
@@ -1943,7 +1944,7 @@ fflush(stderr);
 
 *****************************************************************************/
 
-static long table_list(DB_DATABASE *db, char ***tables)
+static int table_list(DB_DATABASE *db, char ***tables)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -2269,7 +2270,7 @@ fflush(stderr);
 					type = "TEXT";
 				else
 				{
-					sprintf(_buffer, "VARCHAR(%ld)", fp->length);
+					sprintf(_buffer, "VARCHAR(%d)", fp->length);
 					type = _buffer;
 				}
 
@@ -2417,7 +2418,7 @@ fflush(stderr);
 
 *****************************************************************************/
 
-static long field_list(DB_DATABASE *db, char *table, char ***fields)
+static int field_list(DB_DATABASE *db, char *table, char ***fields)
 {
 #ifdef ODBC_DEBUG_HEADER
 fprintf(stderr,"[ODBC][%s][%d]\n",__FILE__,__LINE__);
@@ -2662,7 +2663,7 @@ static int index_exist(DB_DATABASE *db, char *table, char *index)
 
 *****************************************************************************/
 
-static long index_list(DB_DATABASE *db, char *table, char ***indexes)
+static int index_list(DB_DATABASE *db, char *table, char ***indexes)
 {
 	//GB.Error("ODBC does not implement this function - index_list");
 	return (-1);
@@ -2782,7 +2783,7 @@ static int database_exist(DB_DATABASE *db, char *name)
 
 *****************************************************************************/
 
-static long database_list(DB_DATABASE *db, char ***databases)
+static int database_list(DB_DATABASE *db, char ***databases)
 {
 	ODBC_CONN *han = (ODBC_CONN *)db->handle;
 
@@ -2917,7 +2918,7 @@ static int user_exist(DB_DATABASE *db, char *name)
 
 *****************************************************************************/
 
-static long user_list(DB_DATABASE *db, char ***users)
+static int user_list(DB_DATABASE *db, char ***users)
 {
 	ODBC_CONN *han = (ODBC_CONN *)db->handle;
 	GB.NewArray(users, sizeof(char *), 1);
