@@ -101,7 +101,7 @@ static GB_TYPE conv_type(int type)
 
 /* Internal function to convert a database value into a Gambas variant value */
 
-static void conv_data(char *data, GB_VARIANT_VALUE * val, fType type)
+static void conv_data(const char *data, GB_VARIANT_VALUE * val, fType type)
 {
 	GB_VALUE conv;
 	GB_DATE_SERIAL date;
@@ -239,7 +239,7 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, fType type)
 		case ft_WChar:
 		default:
 			val->_string.type = GB_T_CSTRING;
-			val->_string.value = data;
+			val->_string.value = (char *)data;
 			/*GB.NewString(&val->_string.value, data, strlen(data)); */
 
 			break;
@@ -249,12 +249,12 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, fType type)
 
 /* internal function to quote a value stored as a blob */
 
-static void quote_blob(char *data, int len, DB_FORMAT_CALLBACK add)
+static void quote_blob(const char *data, int len, DB_FORMAT_CALLBACK add)
 {
 	int i;
 	unsigned char c;
 	char buffer[2];
-	static char *hexa_digit = "0123456789ABCDEF";
+	static const char *hexa_digit = "0123456789ABCDEF";
 
 	if (len == 0)
 	{
@@ -297,8 +297,7 @@ static void query_get_param(int index, char **str, int *len, char quote)
 
 /* Internal function to run a query */
 
-static int do_query(DB_DATABASE *db, const char *error, Dataset **pres,
-                    const char *qtemp, int nsubst, ...)
+static int do_query(DB_DATABASE *db, const char *error, Dataset **pres, const char *qtemp, int nsubst, ...)
 {
 	SqliteDatabase *conn = (SqliteDatabase *)db->handle;
 	va_list args;
@@ -374,7 +373,7 @@ static int do_query(DB_DATABASE *db, const char *error, Dataset **pres,
 
 /* Internal function to check whether a file is a sqlite database file */
 
-static bool is_sqlite2_database(char *filename)
+static bool is_sqlite2_database(const char *filename)
 {
   /*                   SQLite databases start with the string:
    *                  ** This file contains an SQLite 2.1 database **
@@ -401,7 +400,7 @@ static bool is_sqlite2_database(char *filename)
   return true;
 }
 
-static bool is_sqlite3_database(char *filename)
+static bool is_sqlite3_database(const char *filename)
 {
 	FILE *fp;
 	bool res;
@@ -425,7 +424,7 @@ static bool is_sqlite3_database(char *filename)
 	return true;
 }
 
-bool IsDatabaseFile(char *filename)
+static bool IsDatabaseFile(const char *filename)
 {
 	return is_sqlite3_database(filename) || is_sqlite2_database(filename);
 }
@@ -433,13 +432,13 @@ bool IsDatabaseFile(char *filename)
 
 /* Internal function to locate database and return full qualified */
 /* path. */
-char *FindDatabase(char *name, char *hostName)
+static char *FindDatabase(const char *name, const char *hostName)
 {
 	char *dbhome = NULL;
 	char *fullpath = NULL;
 
 	/* Does Name includes fullpath */
-	if (strcmp(basename(name), name))
+	if (*name == '/')
 	{
 		if (IsDatabaseFile(name))
 			GB.NewString(&fullpath, name, 0);
@@ -497,7 +496,7 @@ char *FindDatabase(char *name, char *hostName)
 /* Internal function to return database home directory */
 /* - GAMBAS_SQLITE_HOMEDB if set or temporary directory /tmp/gambas.%pid%/ */
 
-char *GetDatabaseHome()
+static char *GetDatabaseHome()
 {
 	char *env = NULL;
 	char *dbhome = NULL;
@@ -563,9 +562,8 @@ char *FullPath(char *name)
 
 /* Internal function to walk a dirctory and list files */
 /* Used by database_list                               */
-int WalkDirectory(char *dir, char ***databases)
+static int WalkDirectory(const char *dir, char ***databases)
 {
-
 	DIR *dp;
 	struct dirent *entry;
 	struct stat statbuf;
@@ -619,7 +617,7 @@ int db_version()
 
 *****************************************************************************/
 
-static char *get_quote(void)
+static const char *get_quote(void)
 {
 	return QUOTE_STRING;
 }
@@ -667,7 +665,7 @@ static int open_database(DB_DESC * desc, DB_DATABASE * db)
 	{
 		conn->setDatabase(name);
 	}
-	else if ((db_fullpath = FindDatabase(name, (char *) conn->getHostName())) !=
+	else if ((db_fullpath = FindDatabase(name, conn->getHostName())) !=
 					 NULL)
 	{
 		conn->setDatabase(db_fullpath);
@@ -711,6 +709,8 @@ static int open_database(DB_DESC * desc, DB_DATABASE * db)
 	db->flags.no_table_type = TRUE;
 	db->flags.no_nest = TRUE;
 
+	db->db_name_char = ".";
+
 	db->handle = conn;
 	return FALSE;
 }
@@ -834,11 +834,9 @@ static void format_blob(DB_BLOB * blob, DB_FORMAT_CALLBACK add)
 
 *****************************************************************************/
 
-static int exec_query(DB_DATABASE * db, char *query, DB_RESULT * result,
-											char *err)
+static int exec_query(DB_DATABASE * db, const char *query, DB_RESULT * result, const char *err)
 {
-	return do_query(db, err, (Dataset **) result,
-									query, 0);
+	return do_query(db, err, (Dataset **) result, query, 0);
 }
 
 
@@ -913,7 +911,7 @@ static int query_fill(DB_DATABASE *db, DB_RESULT result, int pos, GB_VARIANT_VAL
 {
 	Dataset *res = (Dataset *) result;
 	int i;
-	char *data;
+	const char *data;
 	GB_VARIANT value;
 
 	if (!next)
@@ -927,7 +925,7 @@ static int query_fill(DB_DATABASE *db, DB_RESULT result, int pos, GB_VARIANT_VAL
 		if (res->fv(i).get_isNull())
 			data = NULL;
 		else
-			data = (char *) res->fv(i).get_asString().data();
+			data = res->fv(i).get_asString().data();
 			
 		//fprintf(stderr, "query_fill: %d.%d %s\n", pos, i, data);
 
@@ -990,7 +988,7 @@ static void blob_read(DB_RESULT result, int pos, int field, DB_BLOB * blob)
 
 static char *field_name(DB_RESULT result, int field)
 {
-	return (char *) (((Dataset *) result)->fieldName(field));
+	return (char *)(((Dataset *) result)->fieldName(field));
 }
 
 
@@ -1006,7 +1004,7 @@ static char *field_name(DB_RESULT result, int field)
 
 *****************************************************************************/
 
-static int field_index(DB_RESULT result, char *name, DB_DATABASE * db)
+static int field_index(DB_RESULT result, const char *name, DB_DATABASE * db)
 {
 	char *fld;
 
@@ -1145,17 +1143,16 @@ static int rollback_transaction(DB_DATABASE * db)
 
 *****************************************************************************/
 
-static int field_info(DB_DATABASE * db, char *table, char *field,
-											DB_FIELD * info);
+static int field_info(DB_DATABASE * db, const char *table, const char *field, DB_FIELD * info);
 
-static int table_init(DB_DATABASE * db, char *table, DB_INFO * info)
+static int table_init(DB_DATABASE * db, const char *table, DB_INFO * info)
 {
-	char *qfield = "PRAGMA table_info('&1')";
+	const char *qfield = "PRAGMA table_info('&1')";
 
 	Dataset *res;
 	int i, n;
 	DB_FIELD *f;
-	char *field;
+	const char *field;
 
 	/* Nom de la table */
 
@@ -1180,7 +1177,7 @@ static int table_init(DB_DATABASE * db, char *table, DB_INFO * info)
 	for (i = 0; i < n; i++)
 	{
 		f = &info->field[i];
-		field = (char *) r->records[i][1].get_asString().data();
+		field = r->records[i][1].get_asString().data();
 
 		if (field_info(db, table, field, f))
 		{
@@ -1221,10 +1218,10 @@ static int table_init(DB_DATABASE * db, char *table, DB_INFO * info)
 
 *****************************************************************************/
 
-static int table_index(DB_DATABASE * db, char *table, DB_INFO * info)
+static int table_index(DB_DATABASE * db, const char *table, DB_INFO * info)
 {
-	char *qindex1 = "PRAGMA index_list('&1')";
-	char *qindex2 = "PRAGMA index_info('&1')";
+	const char *qindex1 = "PRAGMA index_list('&1')";
+	const char *qindex2 = "PRAGMA index_info('&1')";
 
 	Dataset *res;
 	char *sql = NULL;
@@ -1265,8 +1262,17 @@ static int table_index(DB_DATABASE * db, char *table, DB_INFO * info)
 			}
 		}
 
-		res->close();
-		return FALSE;
+		if (i >= (int)r->records.size())
+		{
+			GB.Free(POINTER(&info->index));
+			res->close();	
+			return TRUE;
+		}
+		else
+		{
+			res->close();
+			return FALSE;
+		}
 	}
 
 	for (int i = 0; i < n; i++)
@@ -1292,7 +1298,7 @@ static int table_index(DB_DATABASE * db, char *table, DB_INFO * info)
 
 			for (i = 0; i < info->nindex; i++)
 			{
-				info->index[i] = r->records[i][1].get_asShort();
+				info->index[i] = r->records[i][1].get_asInteger();
 			}
 			break;
 		}
@@ -1333,9 +1339,8 @@ static void table_release(DB_DATABASE * db, DB_INFO * info)
 
 *****************************************************************************/
 
-static int table_exist(DB_DATABASE * db, char *table)
+static int table_exist(DB_DATABASE * db, const char *table)
 {
-
 	const char *query = "select tbl_name from "
 		"( select tbl_name from sqlite_master where type = 'table' union "
 		"select tbl_name from sqlite_temp_master where type = 'table' ) "
@@ -1422,10 +1427,10 @@ static int table_list(DB_DATABASE * db, char ***tables)
 
 *****************************************************************************/
 
-static int table_primary_key(DB_DATABASE * db, char *table, char ***primary)
+static int table_primary_key(DB_DATABASE * db, const char *table, char ***primary)
 {
-	char *qindex1 = "PRAGMA index_list('&1')";
-	char *qindex2 = "PRAGMA index_info('&1')";
+	const char *qindex1 = "PRAGMA index_list('&1')";
+	const char *qindex2 = "PRAGMA index_info('&1')";
 
 	Dataset *res;
 	int i, n;
@@ -1518,7 +1523,7 @@ static int table_primary_key(DB_DATABASE * db, char *table, char ***primary)
 
 *****************************************************************************/
 
-static int table_is_system(DB_DATABASE * db, char *table)
+static int table_is_system(DB_DATABASE * db, const char *table)
 {
 	return strncmp(table, "sqlite_", 7) == 0;
 }
@@ -1533,7 +1538,7 @@ static int table_is_system(DB_DATABASE * db, char *table)
 
 *****************************************************************************/
 
-static char *table_type(DB_DATABASE * db, char *table, char *type)
+static char *table_type(DB_DATABASE * db, const char *table, const char *type)
 {
 	if (type)
 		GB.Error("SQLite does not have any table types");
@@ -1554,7 +1559,7 @@ static char *table_type(DB_DATABASE * db, char *table, char *type)
 
 *****************************************************************************/
 
-static int table_delete(DB_DATABASE * db, char *table)
+static int table_delete(DB_DATABASE * db, const char *table)
 {
 	return
 		do_query(db, "Unable to delete table: &1",
@@ -1577,12 +1582,11 @@ static int table_delete(DB_DATABASE * db, char *table)
 
 *****************************************************************************/
 
-static int table_create(DB_DATABASE * db, char *table, DB_FIELD * fields,
-												char **primary, char *not_used)
+static int table_create(DB_DATABASE * db, const char *table, DB_FIELD * fields, char **primary, const char *not_used)
 {
 	DB_FIELD *fp;
 	int comma;
-	char *type;
+	const char *type;
 	int i;
 	bool no_pkey = FALSE;
 
@@ -1700,7 +1704,7 @@ static int table_create(DB_DATABASE * db, char *table, DB_FIELD * fields,
 
 *****************************************************************************/
 
-static int field_exist(DB_DATABASE * db, char *table, char *field)
+static int field_exist(DB_DATABASE * db, const char *table, const char *field)
 {
 	const char *query = "PRAGMA table_info('&1')";
 
@@ -1745,7 +1749,7 @@ static int field_exist(DB_DATABASE * db, char *table, char *field)
 
 *****************************************************************************/
 
-static int field_list(DB_DATABASE * db, char *table, char ***fields)
+static int field_list(DB_DATABASE * db, const char *table, char ***fields)
 {
 	const char *query = "PRAGMA table_info('&1')";
 
@@ -1792,8 +1796,7 @@ static int field_list(DB_DATABASE * db, char *table, char ***fields)
 
 *****************************************************************************/
 
-static int field_info(DB_DATABASE * db, char *table, char *field,
-											DB_FIELD * info)
+static int field_info(DB_DATABASE * db, const char *table, const char *field, DB_FIELD * info)
 {
 	const char *query = "PRAGMA table_info('&1')";
 
@@ -1887,7 +1890,7 @@ static int field_info(DB_DATABASE * db, char *table, char *field,
 
 *****************************************************************************/
 
-static int index_exist(DB_DATABASE * db, char *table, char *index)
+static int index_exist(DB_DATABASE * db, const char *table, const char *index)
 {
 	const char *query = "select tbl_name from "
 		"( select tbl_name from sqlite_master where type = 'index' and "
@@ -1923,10 +1926,9 @@ static int index_exist(DB_DATABASE * db, char *table, char *index)
 
 *****************************************************************************/
 
-static int index_list(DB_DATABASE * db, char *table, char ***indexes)
+static int index_list(DB_DATABASE * db, const char *table, char ***indexes)
 {
-
-	const char *query =
+  const char *query =
 		"select name from "
 		"( select name from sqlite_master where type = 'index' and tbl_name = '&1' "
 		" union select name from sqlite_temp_master where type = 'index' and "
@@ -1971,13 +1973,12 @@ static int index_list(DB_DATABASE * db, char *table, char ***indexes)
 
 *****************************************************************************/
 
-static int index_info(DB_DATABASE * db, char *table, char *index,
-											DB_INDEX * info)
+static int index_info(DB_DATABASE * db, const char *table, const char *index, DB_INDEX * info)
 {
 	/* sqlite indexes are unique to the database, and not to the table */
 
-	char *qindex1 = "PRAGMA index_list('&1')";
-	char *qindex2 = "PRAGMA index_info('&1')";
+	const char *qindex1 = "PRAGMA index_list('&1')";
+	const char *qindex2 = "PRAGMA index_info('&1')";
 
 	Dataset *res;
 	int i, j, n;
@@ -2039,7 +2040,7 @@ static int index_info(DB_DATABASE * db, char *table, char *index,
 			DB.Query.Add(",");
 
 		/* Get fields in key */
-		DB.Query.Add((char *) r->records[i][2].get_asString().data());
+		DB.Query.Add(r->records[i][2].get_asString().data());
 		i++;
 	}
 
@@ -2064,7 +2065,7 @@ static int index_info(DB_DATABASE * db, char *table, char *index,
 
 *****************************************************************************/
 
-static int index_delete(DB_DATABASE * db, char *table, char *index)
+static int index_delete(DB_DATABASE * db, const char *table, const char *index)
 {
 	return
 		do_query(db, "Unable to delete index: &1",
@@ -2087,8 +2088,7 @@ static int index_delete(DB_DATABASE * db, char *table, char *index)
 
 *****************************************************************************/
 
-static int index_create(DB_DATABASE * db, char *table, char *index,
-												DB_INDEX * info)
+static int index_create(DB_DATABASE * db, const char *table, const char *index, DB_INDEX * info)
 {
 	DB.Query.Init();
 
@@ -2122,7 +2122,7 @@ static int index_create(DB_DATABASE * db, char *table, char *index,
 
 ******************************************************************************/
 
-static int database_exist(DB_DATABASE * db, char *name)
+static int database_exist(DB_DATABASE * db, const char *name)
 {
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 	char *fullpath = NULL;
@@ -2130,7 +2130,7 @@ static int database_exist(DB_DATABASE * db, char *name)
 	if (strcmp(name, ":memory:") == 0)
 		return TRUE;								//Database is loaded in memory only
 
-	if ((fullpath = FindDatabase(name, (char *) conn->getHostName())) != NULL)
+	if ((fullpath = FindDatabase(name, conn->getHostName())) != NULL)
 	{
 		GB.FreeString(&fullpath);
 		return TRUE;
@@ -2162,13 +2162,13 @@ static int database_exist(DB_DATABASE * db, char *name)
 
 static int database_list(DB_DATABASE * db, char ***databases)
 {
-	char *dbhome;
+	const char *dbhome;
 
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 	GB.NewArray(databases, sizeof(char *), 0);
 
 	/* Hostname contains home area */
-	dbhome = (char *) conn->getHostName();
+	dbhome = conn->getHostName();
 	WalkDirectory(dbhome, databases);
 
 	/* Checks GAMBAS_SQLITE_DBHOME if set, or Current Working Directory */
@@ -2205,7 +2205,7 @@ static int database_list(DB_DATABASE * db, char ***databases)
  *   Note: Sqlite doesn't have such a thing.
  ******************************************************************************/
 
-static int database_is_system(DB_DATABASE * db, char *name)
+static int database_is_system(DB_DATABASE * db, const char *name)
 {
 	return FALSE;
 }
@@ -2224,12 +2224,12 @@ static int database_is_system(DB_DATABASE * db, char *name)
  *
  ******************************************************************************/
 
-static int database_delete(DB_DATABASE * db, char *name)
+static int database_delete(DB_DATABASE * db, const char *name)
 {
 	char *fullpath = NULL;
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 
-	if ((fullpath = FindDatabase(name, (char *) conn->getHostName())) == NULL)
+	if ((fullpath = FindDatabase(name, conn->getHostName())) == NULL)
 	{
 		GB.FreeString(&fullpath);
 		GB.Error("Cannot Find  database: &1", name);
@@ -2263,7 +2263,7 @@ static int database_delete(DB_DATABASE * db, char *name)
  *   does not exist.
  ******************************************************************************/
 
-static int database_create(DB_DATABASE * db, char *name)
+static int database_create(DB_DATABASE * db, const char *name)
 {
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 	SqliteDatabase conn2;
@@ -2346,18 +2346,18 @@ _CREATE_DATABASE:
  *
  ******************************************************************************/
 
-static int user_exist(DB_DATABASE * db, char *name)
+static int user_exist(DB_DATABASE * db, const char *name)
 {
 	struct stat dbbuf;
 	struct passwd *fileowner, *user;	// /etc/passwd structure
 	struct group *Group;					// /etc/group structure
 	char **Member;
-	char *Databasefile;
+	const char *Databasefile;
 	bool in_memory;
 
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 
-	if ((Databasefile = (char *) conn->getDatabase()) == NULL)
+	if ((Databasefile = conn->getDatabase()) == NULL)
 	{
 		GB.Error("User_exist:&1", "Unable to get databasename");
 		return FALSE;
@@ -2471,7 +2471,7 @@ static int user_list(DB_DATABASE * db, char ***users)
 	//That is if the user is a member of a group that
 	//is given no rights, but other has all rights,
 	//they should not be able to access
-	char *Databasefile;
+	const char *Databasefile;
 	struct stat buf;
 	struct passwd *user;					// /etc/passwd structure
 	struct group *Group;					// /etc/group structure
@@ -2481,7 +2481,7 @@ static int user_list(DB_DATABASE * db, char ***users)
 
 	SqliteDatabase *conn = (SqliteDatabase *) db->handle;
 
-	if ((Databasefile = (char *) conn->getDatabase()) == NULL)
+	if ((Databasefile = conn->getDatabase()) == NULL)
 	{
 		GB.Error("Unable to get databasename");
 		return -1;
@@ -2594,9 +2594,9 @@ static int user_list(DB_DATABASE * db, char ***users)
  *   rights where privilege allows Write. There is no password.
  ******************************************************************************/
 
-static int user_info(DB_DATABASE * db, char *name, DB_USER * info)
+static int user_info(DB_DATABASE * db, const char *name, DB_USER * info)
 {
-	char *Databasefile;
+	const char *Databasefile;
 
 	//struct stat buf;
 	struct passwd *user;					// /etc/passwd structure
@@ -2615,7 +2615,7 @@ static int user_info(DB_DATABASE * db, char *name, DB_USER * info)
 		return TRUE;
 	}
 
-	if ((Databasefile = (char *) conn->getDatabase()) == NULL)
+	if ((Databasefile = conn->getDatabase()) == NULL)
 	{
 		GB.Error("User_info: &1", "Unable to get databasename");
 		return TRUE;
@@ -2654,7 +2654,7 @@ static int user_info(DB_DATABASE * db, char *name, DB_USER * info)
 
 *****************************************************************************/
 
-static int user_delete(DB_DATABASE * db, char *name)
+static int user_delete(DB_DATABASE * db, const char *name)
 {
 	GB.Error("SQLite users do not exist.");
 	return TRUE;
@@ -2677,7 +2677,7 @@ static int user_delete(DB_DATABASE * db, char *name)
  *   Sqlite: No user create
  ******************************************************************************/
 
-static int user_create(DB_DATABASE * db, char *name, DB_USER * info)
+static int user_create(DB_DATABASE * db, const char *name, DB_USER * info)
 {
 	GB.Error("SQLite users do not exist.");
 	return TRUE;
@@ -2699,7 +2699,7 @@ static int user_create(DB_DATABASE * db, char *name, DB_USER * info)
  *   Sqlite : No user passwords.
  ******************************************************************************/
 
-static int user_set_password(DB_DATABASE * db, char *name, char *password)
+static int user_set_password(DB_DATABASE * db, const char *name, const char *password)
 {
 	GB.Error("SQLite users do not exist.");
 	return TRUE;
