@@ -25,9 +25,8 @@
 #ifndef __CICONVIEW_H
 #define __CICONVIEW_H
 
-#include "gambas.h"
 #include "main.h"
-#include "widgets.h"
+#include "giconview.h"
 
 #ifndef __CICONVIEW_CPP
 
@@ -37,26 +36,20 @@ extern GB_DESC CIconViewDesc[];
 #else
 
 #define THIS ((CICONVIEW *)_object)
-#define ICONVIEW ((gIconView*)THIS->widget)
-#define CICONVIEW_PROPERTIES CWIDGET_PROPERTIES \
-  ",Mode,Sorted,Arrangement,GridX,GridY,WordWrap,Border,ScrollBar"
-
+#define WIDGET ((gIconView*)THIS->widget)
 
 #endif
 
-
-
-typedef struct 
-{
-    GB_BASE ob;
-    gControl *widget;
-	GB_VARIANT_VALUE tag;
-
-	char *icursor;
-	char *item;
-	
-}  CICONVIEW;
-
-
+typedef 
+	struct 
+	{
+		GB_BASE ob;
+		gIconView *widget;
+		GB_VARIANT_VALUE tag;
+		char *item;
+		char *save;	
+		int compare;
+	}  
+	CICONVIEW;
 
 #endif
