@@ -116,7 +116,7 @@ GB_DESC CKeyDesc[] =
   GB_CONSTANT("BackTab", "i", GDK_3270_BackTab),
   GB_CONSTANT("BackSpace", "i", GDK_BackSpace),
   GB_CONSTANT("Return", "i", GDK_Return),
-  GB_CONSTANT("Enter", "i", GDK_3270_Enter),
+  GB_CONSTANT("Enter", "i", GDK_KP_Enter),
   GB_CONSTANT("Insert", "i", GDK_Insert),
   GB_CONSTANT("Delete", "i", GDK_Delete),
   GB_CONSTANT("Pause", "i", GDK_Pause),
@@ -130,10 +130,6 @@ GB_DESC CKeyDesc[] =
   GB_CONSTANT("Down", "i", GDK_Down),
   GB_CONSTANT("PageUp", "i", GDK_Page_Up),
   GB_CONSTANT("PageDown", "i", GDK_Page_Down),
-  //GB_CONSTANT("Shift", "i", 0x1020),
-  //GB_CONSTANT("Control", "i", 0x1021),
-  //GB_CONSTANT("Meta", "i", 0x1022),
-  //GB_CONSTANT("Alt", "i", 0x1023),
   GB_CONSTANT("CapsLock", "i", GDK_Caps_Lock),
   GB_CONSTANT("NumLock", "i", GDK_Num_Lock),
   GB_CONSTANT("ScrollLock", "i", GDK_Scroll_Lock),
