@@ -28,36 +28,28 @@
 #ifndef __CLABEL_H
 #define __CLABEL_H
 
-
 #include "main.h"
-#include "gambas.h"
-#include "widgets.h"
 #include "CWidget.h"
+#include "glabel.h"
 
 #ifndef __CLABEL_CPP
 extern GB_DESC CLabelDesc[];
-extern GB_DESC CTextViewDesc[];
+extern GB_DESC CTextLabelDesc[];
 
 #else
 
 #define THIS ((CLABEL *)_object)
-#define SLABEL ((gSimpleLabel*)THIS->widget)
-#define CLABEL_PROPERTIES CWIDGET_PROPERTIES \
-							",Text,Alignment,Border,AutoResize,Transparent"
-							
-#define CTEXTLABEL_PROPERTIES CWIDGET_PROPERTIES \
-							",Text,Alignment,Border,Transparent"
+#define WIDGET ((gLabel*)THIS->widget)
 
 #endif
 
-
-typedef  struct
-{
-    GB_BASE ob;
-    gControl *widget;
-	GB_VARIANT_VALUE tag;
-
-}  CLABEL;
-
+typedef  
+	struct
+	{
+		GB_BASE ob;
+		gControl *widget;
+		GB_VARIANT_VALUE tag;
+	}
+	CLABEL;
 
 #endif
