@@ -33,17 +33,27 @@
 #include "widgets.h"
 
 
-typedef  struct 
-{
-	GB_BASE  ob;
-	gPicture *picture;
-	void     *fdata;
+typedef 
+  struct 
+  {
+    GB_BASE ob;
+    gPicture *picture;
+  } 
+  CPICTURE;
+
+typedef 
+  struct 
+  {
+    GB_BASE ob;
+    gPicture *picture;
+  }
+  CIMAGE;
 
-} CPICTURE;
 
 #ifndef __CPICTURE_CPP
 
 extern GB_DESC CPictureDesc[];
+extern GB_DESC CImageDesc[];
 
 #else
 
@@ -56,10 +66,13 @@ extern GB_DESC CPictureDesc[];
 
 #endif
 
-#define PICTURE (((CPICTURE*)_object)->picture)
+#define PICTURE (((CPICTURE*)(_object))->picture)
+#define IMAGE (((CIMAGE*)(_object))->picture)
 
+void *GTK_GetImage(GdkPixbuf *buf);
+void *GTK_GetPicture(GdkPixbuf *buf);
 
-void* GTK_GetPicture(GdkPixbuf *buf);
-
+CIMAGE *CIMAGE_create(gPicture *picture);
+CPICTURE *CPICTURE_create(gPicture *picture);
 
 #endif
