@@ -77,7 +77,7 @@ BEGIN_METHOD_VOID(CSCREEN_grab)
 	CPICTURE *pic=NULL;
 	gPicture *buf=gDesktop::grab();
   
-	GB.New((void **)&pic, GB.FindClass("Picture"), 0, 0);
+	GB.New(POINTER(&pic), GB.FindClass("Picture"), 0, 0);
 	if (pic->picture) pic->picture->unref();
 	pic->picture=buf;
 	GB.ReturnObject(pic);
@@ -91,6 +91,11 @@ static void set_font(gFont *font, void *object = 0)
 	MAIN_scale = gDesktop::scale();
 }
 
+static void set_tooltip_font(gFont *font, void *object = 0)
+{
+	gApplication::setToolTipsFont(font);
+}
+
 BEGIN_PROPERTY(CAPP_font)
 
   if (READ_PROPERTY)
@@ -100,6 +105,19 @@ BEGIN_PROPERTY(CAPP_font)
 
 END_PROPERTY
 
+
+BEGIN_PROPERTY(CAPP_tooltip_font)
+
+	CFONT *Font;
+	
+	if (READ_PROPERTY)
+    GB.ReturnObject(CFONT_create(gApplication::toolTipsFont(), set_tooltip_font));
+  else if (VPROP(GB_OBJECT))
+  	set_tooltip_font(((CFONT*)VPROP(GB_OBJECT))->font);
+  
+END_PROPERTY
+
+
 #if 0
 BEGIN_PROPERTY(CSCREEN_font)
 
@@ -176,25 +194,6 @@ BEGIN_PROPERTY(CAPP_tooltip_enabled)
 END_PROPERTY
 
 
-BEGIN_PROPERTY(CAPP_tooltip_font)
-
-  	CFONT *Font;
-	
-	
-	if (READ_PROPERTY)
-	{
-		GB.ReturnObject(CFONT_create(gApplication::toolTipsFont()));
-		return;
-	}
-	
-	Font=(CFONT*)VPROP(GB_OBJECT);
-	if (!Font) return;
-	if (!Font->font) return;
-	gApplication::setToolTipsFont(Font->font);
-  
-END_PROPERTY
-
-
 BEGIN_PROPERTY(CAPP_main_window)
 
   GB.ReturnObject(WINDOW_get_main());
@@ -229,7 +228,7 @@ GB_DESC CDesktopDesc[] =
   GB_STATIC_PROPERTY_READ("Resolution", "i", CSCREEN_resolution),
   GB_STATIC_PROPERTY_READ("Scale","i",CSCREEN_scale),
 
-  GB_STATIC_METHOD("Grab", "Picture", CSCREEN_grab, NULL),
+  GB_STATIC_METHOD("Grab", "Picture", CSCREEN_grab, 0),
 
   GB_END_DECLARE
 };
@@ -247,7 +246,7 @@ GB_DESC CApplicationTooltipDesc[] =
 BEGIN_PROPERTY(CAPP_embedder)
 
   if (READ_PROPERTY)
-    GB.ReturnInteger(CWINDOW_Embedder);
+    GB.ReturnPointer((void *)CWINDOW_Embedder);
   else
   {
     if (CWINDOW_Embedded)
@@ -256,7 +255,7 @@ BEGIN_PROPERTY(CAPP_embedder)
       return;
     }
   
-    CWINDOW_Embedder = VPROP(GB_INTEGER);
+    CWINDOW_Embedder = VPROP(GB_POINTER);
   }
 
 END_PROPERTY
@@ -265,7 +264,7 @@ GB_DESC CApplicationDesc[] =
 {
   GB_DECLARE("Application", 0), GB_VIRTUAL_CLASS(),
 
-  GB_STATIC_METHOD("_exit", NULL, CAPP_exit, NULL),
+  GB_STATIC_METHOD("_exit", NULL, CAPP_exit, 0),
 
   GB_STATIC_PROPERTY("Font", "Font", CAPP_font),
   GB_STATIC_PROPERTY_READ("ActiveControl","Control",CSCREEN_active_control),
@@ -274,7 +273,7 @@ GB_DESC CApplicationDesc[] =
   GB_STATIC_PROPERTY("Busy", "i", CSCREEN_busy),
   GB_STATIC_PROPERTY_SELF("ToolTip", ".ApplicationTooltip"),
   
-  GB_STATIC_PROPERTY("Embedder", "i", CAPP_embedder),
+  GB_STATIC_PROPERTY("Embedder", "p", CAPP_embedder),
   GB_STATIC_PROPERTY("Theme", "s", CAPP_theme),
 
   GB_END_DECLARE
