@@ -34,11 +34,7 @@
 
 BEGIN_METHOD(CSEPARATOR_new, GB_OBJECT parent)
 
-	CCONTAINER *Parent=(CCONTAINER*)VPROP(GB_OBJECT);
-	Parent=(CCONTAINER*)GetContainer ((CWIDGET*)Parent);
-
-	THIS->widget=new gSeparator(Parent->widget);
-	InitControl(THIS->widget,(CWIDGET*)THIS);
+	InitControl(new gSeparator(CONTAINER(VARG(parent))), (CWIDGET*)THIS);
 	
 END_METHOD
 
@@ -48,7 +44,7 @@ GB_DESC CSeparatorDesc[] =
 {
   GB_DECLARE("Separator", sizeof(CSEPARATOR)), GB_INHERITS("Control"),
 
-  GB_METHOD("_new", NULL, CSEPARATOR_new, "(Parent)Container;"),
+  GB_METHOD("_new", 0, CSEPARATOR_new, "(Parent)Container;"),
 
   SEPARATOR_DESCRIPTION,
 
