@@ -25,9 +25,8 @@
 #ifndef __CTABSTRIP_H
 #define __CTABSTRIP_H
 
-#include "gambas.h"
 #include "main.h"
-#include "widgets.h"
+#include "gtabstrip.h"
 #include "CWidget.h"
 #include "CContainer.h"
 
@@ -41,10 +40,6 @@ extern GB_DESC CTabChildrenDesc[];
 #define THIS ((CTABSTRIP*)_object)
 #define TABSTRIP ((gTabStrip*)THIS->widget)
 
-#define CTABSTRIP_PROPERTIES CWIDGET_PROPERTIES \
-  "," CARRANGEMENT_PROPERTIES ",Count,Index,Text,Picture,Orientation"
-
-
 #endif
 
 typedef  struct
