@@ -323,11 +323,11 @@ END_METHOD
 
 BEGIN_PROPERTY(CPLUGIN_client)
 
-	GB.ReturnInteger( ((gPlugin*)((CPLUGIN*)_object)->widget)->client() );
+	GB.ReturnPointer((void *)((gPlugin*)((CPLUGIN*)_object)->widget)->client() );
 
 END_PROPERTY
 
-BEGIN_METHOD(CPLUGIN_embed, GB_INTEGER id; GB_BOOLEAN prepared)
+BEGIN_METHOD(CPLUGIN_embed, GB_POINTER id; GB_BOOLEAN prepared)
 
 	((gPlugin*)((CPLUGIN*)_object)->widget)->plug(VARG(id), VARGOPT(prepared, TRUE));
 
@@ -769,27 +769,27 @@ GB_DESC CWidgetDesc[] =
   GB_NOT_CREATABLE(),
   GB_HOOK_CHECK(CWIDGET_check),
 
-  //GB_METHOD("_free", NULL, CWIDGET_delete, NULL),
+  //GB_METHOD("_free", 0, CWIDGET_delete, 0),
 
-  GB_METHOD("Move", NULL, CWIDGET_move, "(X)i(Y)i[(Width)i(Height)i]"),
-  GB_METHOD("Resize", NULL, CWIDGET_resize, "(Width)i(Height)i"),
-  GB_METHOD("MoveScaled", NULL, CWIDGET_moveScaled, "(X)f(Y)f[(Width)f(Height)f]"),
-  GB_METHOD("ResizeScaled", NULL, CWIDGET_resizeScaled, "(Width)f(Height)f"),
-  GB_METHOD("Delete", NULL, CWIDGET_delete, NULL),
-  GB_METHOD("Show", NULL, CWIDGET_show, NULL),
-  GB_METHOD("Hide", NULL, CWIDGET_hide, NULL),
-  GB_METHOD("Reparent",NULL,CWIDGET_reparent,"(Parent)Container;[(X)i(Y)i]"),
+  GB_METHOD("Move", 0, CWIDGET_move, "(X)i(Y)i[(Width)i(Height)i]"),
+  GB_METHOD("Resize", 0, CWIDGET_resize, "(Width)i(Height)i"),
+  GB_METHOD("MoveScaled", 0, CWIDGET_moveScaled, "(X)f(Y)f[(Width)f(Height)f]"),
+  GB_METHOD("ResizeScaled", 0, CWIDGET_resizeScaled, "(Width)f(Height)f"),
+  GB_METHOD("Delete", 0, CWIDGET_delete, 0),
+  GB_METHOD("Show", 0, CWIDGET_show, 0),
+  GB_METHOD("Hide", 0, CWIDGET_hide, 0),
+  GB_METHOD("Reparent",0,CWIDGET_reparent,"(Parent)Container;[(X)i(Y)i]"),
   
-  GB_METHOD("Raise", NULL, CWIDGET_raise, NULL),
-  GB_METHOD("Lower", NULL, CWIDGET_lower, NULL),
+  GB_METHOD("Raise", 0, CWIDGET_raise, 0),
+  GB_METHOD("Lower", 0, CWIDGET_lower, 0),
 
   GB_PROPERTY("Next", "Control", CWIDGET_next),
   GB_PROPERTY("Previous", "Control", CWIDGET_previous),
   
-  GB_METHOD("SetFocus", NULL, CWIDGET_set_focus, NULL),
-  GB_METHOD("Refresh", NULL, CWIDGET_refresh, "[(X)i(Y)i(Width)i(Height)i]"),
-  GB_METHOD("Grab", "Picture", CWIDGET_grab, NULL),
-  GB_METHOD("Drag", NULL, CWIDGET_drag, "(Data)v[(Format)s]"),
+  GB_METHOD("SetFocus", 0, CWIDGET_set_focus, 0),
+  GB_METHOD("Refresh", 0, CWIDGET_refresh, "[(X)i(Y)i(Width)i(Height)i]"),
+  GB_METHOD("Grab", "Picture", CWIDGET_grab, 0),
+  GB_METHOD("Drag", 0, CWIDGET_drag, "(Data)v[(Format)s]"),
 
   GB_PROPERTY("X", "i", CWIDGET_x),
   GB_PROPERTY("Y", "i", CWIDGET_y),
@@ -824,25 +824,25 @@ GB_DESC CWidgetDesc[] =
 
   GB_PROPERTY_READ("Parent", "Container", CWIDGET_parent),
   GB_PROPERTY_READ("Window", "Window", CWIDGET_window),
-  GB_PROPERTY_READ("Id", "i", CWIDGET_id),
-  GB_PROPERTY_READ("Handle", "i", CWIDGET_id),
+  GB_PROPERTY_READ("Id", "p", CWIDGET_id),
+  GB_PROPERTY_READ("Handle", "p", CWIDGET_id),
 
-  GB_EVENT("Enter", NULL, NULL, &EVENT_Enter),
-  GB_EVENT("GotFocus", NULL, NULL, &EVENT_GotFocus),
-  GB_EVENT("LostFocus", NULL, NULL, &EVENT_LostFocus),
-  GB_EVENT("KeyPress", NULL, NULL, &EVENT_KeyPress),
-  GB_EVENT("KeyRelease", NULL, NULL, &EVENT_KeyRelease),
-  GB_EVENT("Leave", NULL, NULL, &EVENT_Leave),
-  GB_EVENT("MouseDown", NULL, NULL, &EVENT_MouseDown),
-  GB_EVENT("MouseMove", NULL, NULL, &EVENT_MouseMove),
-  GB_EVENT("MouseDrag", NULL, NULL, &EVENT_MouseDrag),
-  GB_EVENT("MouseUp", NULL, NULL, &EVENT_MouseUp),
-  GB_EVENT("MouseWheel", NULL, NULL, &EVENT_MouseWheel),
-  GB_EVENT("DblClick", NULL, NULL, &EVENT_DblClick),
-  GB_EVENT("Menu", NULL, NULL, &EVENT_Menu),
-  GB_EVENT("Drag", NULL, NULL, &EVENT_Drag),
-  GB_EVENT("DragMove", NULL, NULL, &EVENT_DragMove),
-  GB_EVENT("Drop", NULL, NULL, &EVENT_Drop),
+  GB_EVENT("Enter", 0, 0, &EVENT_Enter),
+  GB_EVENT("GotFocus", 0, 0, &EVENT_GotFocus),
+  GB_EVENT("LostFocus", 0, 0, &EVENT_LostFocus),
+  GB_EVENT("KeyPress", 0, 0, &EVENT_KeyPress),
+  GB_EVENT("KeyRelease", 0, 0, &EVENT_KeyRelease),
+  GB_EVENT("Leave", 0, 0, &EVENT_Leave),
+  GB_EVENT("MouseDown", 0, 0, &EVENT_MouseDown),
+  GB_EVENT("MouseMove", 0, 0, &EVENT_MouseMove),
+  GB_EVENT("MouseDrag", 0, 0, &EVENT_MouseDrag),
+  GB_EVENT("MouseUp", 0, 0, &EVENT_MouseUp),
+  GB_EVENT("MouseWheel", 0, 0, &EVENT_MouseWheel),
+  GB_EVENT("DblClick", 0, 0, &EVENT_DblClick),
+  GB_EVENT("Menu", 0, 0, &EVENT_Menu),
+  GB_EVENT("Drag", 0, 0, &EVENT_Drag),
+  GB_EVENT("DragMove", 0, 0, &EVENT_DragMove),
+  GB_EVENT("Drop", 0, 0, &EVENT_Drop),
 
 	CONTROL_DESCRIPTION,
 
@@ -853,16 +853,16 @@ GB_DESC CPluginDesc[] =
 {
   GB_DECLARE("Embedder", sizeof(CPLUGIN)), GB_INHERITS("Control"),
 
-  GB_METHOD("_new", NULL, CPLUGIN_new, "(Parent)Container;"),
-  GB_METHOD("Embed", NULL, CPLUGIN_embed, "(Client)i[(Prepared)b]"),
-  GB_METHOD("Discard", NULL, CPLUGIN_discard, NULL),
+  GB_METHOD("_new", 0, CPLUGIN_new, "(Parent)Container;"),
+  GB_METHOD("Embed", 0, CPLUGIN_embed, "(Client)p[(Prepared)b]"),
+  GB_METHOD("Discard", 0, CPLUGIN_discard, 0),
   
-  GB_PROPERTY_READ("Client", "i", CPLUGIN_client),
+  GB_PROPERTY_READ("Client", "p", CPLUGIN_client),
   //GB_PROPERTY("Border", "i<Border>", CPLUGIN_border),
   
-  GB_EVENT("Embed", NULL, NULL, &EVENT_Plugged),
-  GB_EVENT("Close", NULL, NULL, &EVENT_Unplugged),
-  GB_EVENT("Error", NULL, NULL, &EVENT_PlugError), /* TODO */
+  GB_EVENT("Embed", 0, 0, &EVENT_Plugged),
+  GB_EVENT("Close", 0, 0, &EVENT_Unplugged),
+  GB_EVENT("Error", 0, 0, &EVENT_PlugError), /* TODO */
   
   EMBEDDER_DESCRIPTION,
   
