@@ -25,15 +25,37 @@
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ***************************************************************************/
+
 #ifndef GB_GTK_H
 #define GB_GTK_H
 
-typedef  struct 
-{
-	long  version;
-	void* (*GetPicture)(GdkPixbuf *buf);
-	void* (*GetImage)(GdkPixbuf *buf);
-	void* _null;
+#include "gambas.h"
+#include <gdk/gdk.h>
+
+#define GTK_INTERFACE_VERSION 1
+
+typedef
+	struct 
+	{
+		intptr_t version;
+		void *(*GetPicture)(GdkPixbuf *buf);
+		void *(*GetImage)(GdkPixbuf *buf);
+		struct {
+			void (*FooterProperty)(void *, void *);
+			void (*ColumnFooterTextProperty)(void *, void *);
+			void (*ColumnsGetMethod)(void *, void *);
+			}
+			GridView;
+		struct {
+			void* (*GetDrawable)(void *);
+			void* (*GetStyle)(void *);
+			int   (*GetState)(void *);
+			int   (*GetShadow)(void *);
+			void  (*SetState)(void *,int);
+			void  (*SetShadow)(void *,int);
+		} Draw;
+		void *_null;
+	}  
+	GTK_INTERFACE;
 
-}  GTK_INTERFACE;
 #endif
