@@ -122,16 +122,17 @@ char* gStoreList_itemText(GtkListStore *store,int ind)
 	return ret;
 }
 
-void gStoreList_setItemText(GtkListStore *store,int ind,char *txt)
+void gStoreList_setItemText(GtkListStore *store,int ind, const char *txt)
 {
 	GtkTreeIter iter;
 
+	if (!txt) txt = "";
 	if (gStoreList_Iter(store,&iter,ind)) return;
 	gtk_list_store_set (store,&iter,0,txt,-1);
 }
 
 
-int gStoreList_Find(GtkListStore *store,char *ptr)
+int gStoreList_Find(GtkListStore *store, const char *ptr)
 {
 	int len=0;
 	char *buf;
@@ -365,8 +366,8 @@ gComboBox::gComboBox(gContainer *parent) : gTextBox(parent, true)
 	
 	cell = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(widget), cell, true);
-	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(widget), cell, "text", 0, NULL);
-	g_object_set(cell, "ypad", 0, NULL);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(widget), cell, "text", 0, (void *)NULL);
+	g_object_set(cell, "ypad", 0, (void *)NULL);
 
 	realize(false);
 	
@@ -478,7 +479,7 @@ void gComboBox::setIndex(int vl)
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget),vl);
 }
 
-void gComboBox::setItemText(int ind,char *txt)
+void gComboBox::setItemText(int ind, const char *txt)
 {
 	int buf;
 	
@@ -544,14 +545,14 @@ void gComboBox::setSorted(bool vl)
 	if (sort) gStoreList_sortData(STORE_LIST);
 }
 
-void gComboBox::setText(char *vl)
+void gComboBox::setText(const char *vl)
 {
 	setIndex(find(vl));
 	if (entry)
 		gTextBox::setText(vl);
 }
 
-void gComboBox::add(char *vl,int pos)
+void gComboBox::add(const char *vl,int pos)
 {
 	GtkTreeIter iter,curr;
 	GtkListStore *store;
@@ -563,6 +564,9 @@ void gComboBox::add(char *vl,int pos)
 	
 	ind = index();
 	
+	if (!vl) 
+		vl = "";
+	
 	store = (GtkListStore*)gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
 	
 	if (!gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store),&iter))
@@ -590,7 +594,7 @@ void gComboBox::clear()
 	setIndex(-1);
 }
 
-int gComboBox::find(char *ptr)
+int gComboBox::find(const char *ptr)
 {
 	return gStoreList_Find(STORE_LIST, ptr);
 }
@@ -612,7 +616,7 @@ void gComboBox::resize(int w, int h)
 void gComboBox::setFont(gFont *f)
 {
 	gControl::setFont(f);
-	g_object_set(G_OBJECT(cell), "font-desc", font() ? font()->desc() : NULL, NULL);
+	g_object_set(G_OBJECT(cell), "font-desc", font() ? font()->desc() : NULL, (void *)NULL);
 	if (entry)
 		gtk_widget_modify_font(entry, font() ? font()->desc() : NULL);
 }
