@@ -87,6 +87,8 @@ static void resize_container(gControl *cont, int w, int h)
 #define IS_DESIGN(_object) (((gControl*)_object)->design())
 #define IS_WIDGET_VISIBLE(_widget)  (((gControl*)_widget)->isVisible())
 
+#define CAN_ARRANGE(_object) (IS_WIDGET_VISIBLE(GET_WIDGET(_object)) || (((gControl *)_object)->isTopLevel() && ((gMainWindow *)_object)->opened))
+
 // BM: ClientX() & ClientY() are relative to the border.
 // We need X & Y relative to the container widget.
 
@@ -383,11 +385,13 @@ void gContainer::insert(gControl *child)
 	
 	//g_debug("gContainer::insert: visible = %d", isReallyVisible());
 	performArrange();
+	updateFocusChain();
 }
 
 void gContainer::remove(gControl *child)
 {
 	ch_list = g_list_remove(ch_list, child);
+	updateFocusChain();
 }
 
 
@@ -507,3 +511,26 @@ void gContainer::setVisible(bool vl)
 		performArrange();
 }
 
+void gContainer::updateFocusChain()
+{
+	GList *chain = NULL;
+	GList *iter = ch_list;
+	gControl *child;
+	
+	//fprintf(stderr, "updateFocusChain()\n");
+	
+	iter = g_list_first(ch_list);
+	while (iter)
+	{
+		child = (gControl*)(iter->data);
+		//fprintf(stderr, "%s\n", child->name());	
+	  chain = g_list_prepend(chain, child->border);
+		iter = iter->next;
+	}
+	
+	chain = g_list_reverse(chain);
+	
+	gtk_container_set_focus_chain(GTK_CONTAINER(widget), chain);
+	
+	g_list_free(chain);
+}
