@@ -102,9 +102,9 @@ gPlugin::gPlugin(gContainer *parent) : gControl(parent)
 {
 	g_typ=Type_gPlugin;
 	
-	border=gtk_event_box_new();
-	widget=gtk_socket_new();
-	realize(true);
+	border=gtk_socket_new();
+	widget=border;
+	realize(false);
 	
 	onPlug=NULL;
 	onUnplug=NULL;
@@ -112,32 +112,24 @@ gPlugin::gPlugin(gContainer *parent) : gControl(parent)
 	g_signal_connect(G_OBJECT(widget),"plug-removed",G_CALLBACK(gPlugin_OnUnplug),(gpointer)this);
 	g_signal_connect(G_OBJECT(widget),"plug-added",G_CALLBACK(gPlugin_OnPlug),(gpointer)this);
 
-	g_object_set(G_OBJECT(widget),"can-focus",TRUE, NULL);
+	g_object_set(G_OBJECT(widget),"can-focus",TRUE, (void *)NULL);
 }
 
-int gPlugin::client()
+long gPlugin::client()
 {
 	GdkNativeWindow win=gtk_socket_get_id(GTK_SOCKET(widget));
-	return (int)win;
+	return (long)win;
 }
 
-int gPlugin::handle()
+void gPlugin::plug(long id,bool prepared)
 {
-	GdkNativeWindow win=gtk_socket_get_id(GTK_SOCKET(widget));
-	return (int)win;
-}
+	//int bc;
 
-void gPlugin::plug(int id,bool prepared)
-{
-	int bc;
-
-	for (bc=0; bc<10; bc++)
-	{
+	//for (bc=0; bc<10; bc++)
+	//{
 		if (!prepared) gtk_socket_steal(GTK_SOCKET(widget),(GdkNativeWindow)id);
 		else gtk_socket_add_id(GTK_SOCKET(widget),(GdkNativeWindow)id);
-	}
-
-	
+	//}
 }
 
 void gPlugin::discard()
@@ -159,7 +151,7 @@ void gPlugin::discard()
 	color = foreground();
 	gtk_widget_destroy(widget);
 	
-	widget=gtk_socket_new();
+	border=widget=gtk_socket_new();
 	fr=gtk_bin_get_child(GTK_BIN(border));
 	gtk_container_add(GTK_CONTAINER(fr),widget);
 	gtk_widget_show(widget);
@@ -219,7 +211,7 @@ void gControl::initAll(gContainer *parent)
 	have_cursor = false;
 	use_base = false;
 	mous=-1;
-	pr=parent;
+	pr = parent;
 	_name=NULL;
 	visible = false;
 	_locked = 0;
@@ -228,6 +220,8 @@ void gControl::initAll(gContainer *parent)
 	_action = false;
 	_dirty_pos = _dirty_size = false;
 	_tracking = false;
+	no_input_method = false;
+	_no_default_mouse_event = false;
 
 	onFinish=NULL;
 	onFocusEvent=NULL;
@@ -623,7 +617,7 @@ gFont* gControl::font()
 
 void gControl::setFont(gFont *ft)
 {
-	gFont::assign(&fnt, ft);
+	gFont::set(&fnt, ft->copy());
 	gtk_widget_modify_font(widget, fnt ? fnt->desc() : NULL);
 	resize();
 }
@@ -762,11 +756,11 @@ gMainWindow* gControl::topLevel()
 	return (gMainWindow *)child;
 }
 
-int gControl::handle()
+long gControl::handle()
 {
 	#ifndef GAMBAS_DIRECTFB
 	#ifdef GDK_WINDOWING_X11
-	return (int)GDK_WINDOW_XID(border->window);
+	return (long)GDK_WINDOW_XID(border->window);
 	#else
 	stub("no-X11/gControl::handle()");
 	return 0;
@@ -824,7 +818,10 @@ void gControl::setFocus()
 	gMainWindow *win = window();
 	
 	if (win->isVisible())
+	{
+		//if (isVisible() && bufW > 0 && bufH > 0)
 		gtk_widget_grab_focus(widget);
+	}
 	else
 		win->focus = this;
 }
@@ -922,6 +919,7 @@ void gControl::lower()
 		
 	pr->ch_list = g_list_remove(pr->ch_list, this);
 	pr->ch_list = g_list_prepend(pr->ch_list, this);
+	pr->updateFocusChain();
 }
 
 void gControl::raise()
@@ -949,6 +947,7 @@ void gControl::raise()
 	
 	pr->ch_list = g_list_remove(pr->ch_list, this);
 	pr->ch_list = g_list_append(pr->ch_list, this);
+	pr->updateFocusChain();
 }
 
 void gControl::setNext(gControl *ctrl)
@@ -976,12 +975,16 @@ void gControl::setNext(gControl *ctrl)
 	
 	pr->ch_list = g_list_remove(pr->ch_list, this);
 	pr->ch_list = g_list_insert_before(pr->ch_list, next, this);
+	pr->updateFocusChain();
 	#endif
 }
 
 void gControl::setPrevious(gControl *ctrl)
 {
-	setNext(ctrl->next());
+	if (!ctrl)
+		lower();
+	else
+		setNext(ctrl->next());
 }
 
 gPicture* gControl::grab()
@@ -1121,7 +1124,8 @@ static gboolean cb_frame_expose(GtkWidget *wid, GdkEventExpose *e, gControl *con
 
 static void cb_size_allocate(GtkWidget *wid, GdkEventExpose *e, gContainer *container)
 {
-	container->performArrange();
+	if (!container->isTopLevel())
+		container->performArrange();
 }
 
 
@@ -1192,7 +1196,7 @@ void gControl::realize(bool make_frame)
   if (frame)
 		g_signal_connect_after(G_OBJECT(frame), "expose-event", G_CALLBACK(cb_frame_expose), (gpointer)this);
 		
-	if (isContainer() && widget != border && !isTopLevel())
+	if (isContainer() && widget != border)
 		g_signal_connect(G_OBJECT(widget), "size-allocate", G_CALLBACK(cb_size_allocate), (gpointer)this);
 }
 
@@ -1377,11 +1381,11 @@ void gControl::emit(void *signal)
 	(*((void (*)(gControl *))signal))(this);
 }
 
-void gControl::emit(void *signal, int arg)
+void gControl::emit(void *signal, intptr_t arg)
 {
 	if (!signal || locked())
 		return;
-	(*((void (*)(gControl *, int))signal))(this, arg);
+	(*((void (*)(gControl *, intptr_t))signal))(this, arg);
 }
 
 void gControl::reparent(gContainer *newpr, int x, int y)
@@ -1410,11 +1414,9 @@ void gControl::reparent(gContainer *newpr, int x, int y)
 			gtk_widget_reparent(border, newpr->getContainer());
 			oldpr->remove(this);
 			oldpr->performArrange();
-			newpr->insert(this);
-			move(x, y);
 		}
-		else		
-			newpr->insert(this, x, y);
+		
+		newpr->insert(this, x, y);
 	}
 }
 
