@@ -107,7 +107,7 @@ void gDraw::initGC()
 	if (dr) 
 	{
 		g_object_ref(G_OBJECT(dr));
-		gc=gdk_gc_new(dr);
+		gc = gdk_gc_new(dr);
 		gdk_gc_set_fill(gc,GDK_SOLID);
 		#ifdef GOT_X11_PLATFORM
 		XSetArcMode(GDK_GC_XDISPLAY(gc), GDK_GC_XGC(gc), ArcPieSlice);
@@ -203,8 +203,8 @@ void gDraw::connect(gPicture *wid)
 	dr = wid->getPixmap();
 	drm = wid->getMask();
 
-	stl=gtk_style_new();
-	gtk_style_attach(stl,(GdkWindow*)dr);
+	stl = gtk_style_copy(gt_get_style("GtkButton", GTK_TYPE_BUTTON));
+	stl = gtk_style_attach(stl, (GdkWindow*)dr);
 	
 	wid->invalidate();
 	initGC();
@@ -946,7 +946,7 @@ gFont* gDraw::font()
 
 void gDraw::setFont(gFont *f)
 {
-  gFont::assign(&ft, f);
+  gFont::set(&ft, f->copy());
 }
 
 
