@@ -196,6 +196,7 @@ static gboolean tbheader_move(GtkWidget *wid, GdkEventMotion *e, gGridView *data
 static void tblateral_select(gGridView *data, int bcurrent, bool move)
 {
 	int bc, col;
+	bool sel_changed;
 	
 	data->getCursor(NULL, &col);
 	
@@ -208,6 +209,7 @@ static void tblateral_select(gGridView *data, int bcurrent, bool move)
 			if (!data->rowSelected(bcurrent))
 			{
 				data->setCursor(bcurrent, col);
+				data->emit(SIGNAL(data->onSelect));
 			}
 			break;
 			
@@ -215,10 +217,14 @@ static void tblateral_select(gGridView *data, int bcurrent, bool move)
 			if (!move)
 			{
 				data->sel_row = bcurrent;
-				data->sel_current = bcurrent;
-				data->clearSelection();
-				data->setRowSelected(bcurrent, true);
 				data->setCursor(bcurrent, col);
+				if (data->sel_current != bcurrent)
+				{
+					data->sel_current = bcurrent;
+					data->clearSelection();
+					data->setRowSelected(bcurrent, true);
+					data->emit(SIGNAL(data->onSelect));
+				}
 			}
 			else
 			{
@@ -235,14 +241,14 @@ static void tblateral_select(gGridView *data, int bcurrent, bool move)
 					{
 						for (bc = bcurrent; bc <= data->sel_current; bc++)
 							data->setRowSelected(bc, true);
+						sel_changed = true;
 					}
 					else
 					{
 						for (bc = data->sel_current; bc < bcurrent; bc++)
 							data->setRowSelected(bc, false);
+						sel_changed = true;
 					}
-					
-					data->sel_current = bcurrent;
 				}
 				else
 				{
@@ -262,8 +268,12 @@ static void tblateral_select(gGridView *data, int bcurrent, bool move)
 						for (bc = bcurrent + 1; bc <= data->sel_current; bc++)
 							data->setRowSelected(bc, false);
 					}
-					
+				}
+				
+				if (data->sel_current != bcurrent)
+				{
 					data->sel_current = bcurrent;
+					data->emit(SIGNAL(data->onSelect));
 				}
 				
 				data->setCursor(bcurrent, col);
@@ -517,8 +527,7 @@ static gboolean tbheader_expose(GtkWidget *wid,GdkEventExpose *e,gGridView *data
 				"xalign", 0.5,
 				"yalign", 0.5,
 				"font-desc", data->font()->desc(),
-				NULL
-				);
+				(void *)NULL);
 			rect.x=bpos;
 			rect.y=0;
 			rect.width=pw-1;
@@ -588,7 +597,7 @@ static gboolean tblateral_expose(GtkWidget *wid,GdkEventExpose *e,gGridView *dat
 			"xalign", 0.5,
 			"yalign", 0.5,
 			"font-desc", data->font()->desc(),
-			NULL);
+			(void *)NULL);
 		
 		rect.x = 0;
 		rect.y = bpos;
@@ -618,7 +627,7 @@ static gboolean tbheader_release(GtkWidget *wid,GdkEventButton *e,gGridView *dat
 	bcurrent = data->findColumn((int)e->x + data->scrollX());
 	if (bcurrent<0) return false;
 
-	g_object_get(G_OBJECT(wid),"name",&buf,NULL);
+	g_object_get(G_OBJECT(wid),"name",&buf,(void *)NULL);
 	if (buf)
 	{
 		if (!strcmp(buf,"gambas-grid-footer")) bfooter=true;
@@ -663,7 +672,7 @@ static gboolean cb_scroll(GtkWidget *wid, GdkEventScroll *e, gGridView *data)
 	else
 		adj = gtk_range_get_adjustment(GTK_RANGE(data->hbar));
 	
-	g_object_get(G_OBJECT(adj), "step-increment", &step, NULL);
+	g_object_get(G_OBJECT(adj), "step-increment", &step, (void *)NULL);
 	
 	switch (e->direction)
 	{
@@ -720,6 +729,7 @@ gGridView::gGridView(gContainer *parent) : gControl(parent)
 
 	onChange = NULL;
 	onActivate = NULL;
+	onSelect = NULL;
 	onScroll = NULL;
 	onClick = NULL;
 	onColumnClick = NULL;
@@ -734,11 +744,13 @@ gGridView::gGridView(gContainer *parent) : gControl(parent)
 	cursor_row=-1;
 	sel_row=-1;
 	sel_mode=0;
+	sel_current = -1;
 	scroll=3;
 	hdata=NULL;
 	vdata=NULL;
 	_last_col_width = 0;
 	scroll_timer = 0;
+	_updating_last_column = false;
 
 	border=gtk_event_box_new();
 	widget=gtk_table_new(3,3,FALSE);
@@ -767,6 +779,7 @@ gGridView::gGridView(gContainer *parent) : gControl(parent)
 	
 	render=new gTableRender(this);
 
+	_no_default_mouse_event = true;
 	realize(true);
 
 	gtk_widget_add_events(border,GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
@@ -781,8 +794,8 @@ gGridView::gGridView(gContainer *parent) : gControl(parent)
 	gtk_widget_add_events(footer,GDK_BUTTON_RELEASE_MASK);
 	gtk_widget_add_events(lateral,GDK_BUTTON_RELEASE_MASK);
 	
-	g_object_set(G_OBJECT(header),"name","gambas-grid-header",NULL);
-	g_object_set(G_OBJECT(footer),"name","gambas-grid-footer",NULL);
+	g_object_set(G_OBJECT(header),"name","gambas-grid-header",(void *)NULL);
+	g_object_set(G_OBJECT(footer),"name","gambas-grid-footer",(void *)NULL);
 
 	g_signal_connect_after(G_OBJECT(border),"size-allocate",G_CALLBACK(gGridView_configure),(void*)this);
 	g_signal_connect(G_OBJECT(border), "key-press-event", G_CALLBACK(cb_keypress), this);
@@ -805,15 +818,20 @@ gGridView::gGridView(gContainer *parent) : gControl(parent)
 		
 	g_signal_connect_after(G_OBJECT(contents),"event",G_CALLBACK(cb_contents_button_press),this);
 	g_signal_connect(G_OBJECT(contents),"motion-notify-event",G_CALLBACK(tblateral_move),this);
+	
+	g_signal_connect(G_OBJECT(contents),"button-release-event",G_CALLBACK(gcb_button_release),(gpointer)this);
+	g_signal_connect(G_OBJECT(contents),"button-press-event",G_CALLBACK(gcb_button_press),(gpointer)this);
+	
 	g_signal_connect(G_OBJECT(contents),"button-press-event",G_CALLBACK(tblateral_press),this);
 	g_signal_connect(G_OBJECT(contents),"button-release-event",G_CALLBACK(tblateral_release),this);
 	
+
 	//g_signal_connect(G_OBJECT(contents),"event",G_CALLBACK(gridview_release),this);
 
-	g_object_set(G_OBJECT(vbar),"visible",FALSE,NULL);
-	g_object_set(G_OBJECT(hbar),"visible",FALSE,NULL);
-	g_object_set(G_OBJECT(footer),"visible",FALSE,NULL);
-	g_object_set(G_OBJECT(widget),"can-focus",TRUE,NULL);
+	g_object_set(G_OBJECT(vbar),"visible",FALSE,(void *)NULL);
+	g_object_set(G_OBJECT(hbar),"visible",FALSE,(void *)NULL);
+	g_object_set(G_OBJECT(footer),"visible",FALSE,(void *)NULL);
+	g_object_set(G_OBJECT(widget),"can-focus",TRUE,(void *)NULL);
 
 	gtk_widget_realize(footer);
 	gtk_widget_realize(contents);
@@ -937,13 +955,13 @@ void gGridView::calculateBars()
 	
 	if (bh != GTK_WIDGET_VISIBLE(hbar))
 	{
-		g_object_set(G_OBJECT(hbar),"visible",bh,NULL);
+		g_object_set(G_OBJECT(hbar),"visible",bh,(void *)NULL);
 		if (!bh)
 			setScrollX(0);
 	}
 	if (bv != GTK_WIDGET_VISIBLE(vbar))
 	{
-		g_object_set(G_OBJECT(vbar),"visible",bv,NULL);
+		g_object_set(G_OBJECT(vbar),"visible",bv,(void *)NULL);
 		if (!bv)
 			setScrollY(0);
 	}
@@ -953,7 +971,7 @@ void gGridView::calculateBars()
 		gtk_range_set_range(GTK_RANGE(hbar),0,render->width());
 		gtk_range_set_increments(GTK_RANGE(hbar),render->getColumnSize(0),vw);
 		adj=gtk_range_get_adjustment(GTK_RANGE(hbar));
-		g_object_set(G_OBJECT(adj),"page-size",(gfloat)vw,NULL);
+		g_object_set(G_OBJECT(adj),"page-size",(gfloat)vw,(void *)NULL);
 	}
 
 	if (bv)
@@ -961,7 +979,7 @@ void gGridView::calculateBars()
 		gtk_range_set_range(GTK_RANGE(vbar),0,render->height());
 		gtk_range_set_increments(GTK_RANGE(vbar),render->getRowSize(0),vh);
 		adj=gtk_range_get_adjustment(GTK_RANGE(vbar));
-		g_object_set(G_OBJECT(adj),"page-size",(gfloat)vh,NULL);
+		g_object_set(G_OBJECT(adj),"page-size",(gfloat)vh,(void *)NULL);
 	}
 }
 
@@ -992,8 +1010,8 @@ void gGridView::setScrollBar(int vl)
 	if (vl==scroll) return;
 
 	scroll=vl;
-	if ( !(scroll & 1) ) g_object_set(G_OBJECT(hbar),"visible",FALSE,NULL);
-	if ( !(scroll & 2) ) g_object_set(G_OBJECT(vbar),"visible",FALSE,NULL);
+	if ( !(scroll & 1) ) g_object_set(G_OBJECT(hbar),"visible",FALSE,(void *)NULL);
+	if ( !(scroll & 2) ) g_object_set(G_OBJECT(vbar),"visible",FALSE,(void *)NULL);
 	calculateBars();
 }
 
@@ -1074,7 +1092,7 @@ int gGridView::visibleLeft()
 	gboolean vl;
 	int w;
 
-	g_object_get(G_OBJECT(lateral),"visible",&vl,NULL);
+	g_object_get(G_OBJECT(lateral),"visible",&vl,(void *)NULL);
 	if (!vl) return 0;
 	gtk_widget_get_size_request(lateral,&w,NULL);
 	return w;
@@ -1085,7 +1103,7 @@ int gGridView::visibleTop()
 	gboolean vl;
 	int h;
 
-	g_object_get(G_OBJECT(header),"visible",&vl,NULL);
+	g_object_get(G_OBJECT(header),"visible",&vl,(void *)NULL);
 	if (!vl) return 0;
 	gtk_widget_get_size_request(header,NULL,&h);
 	return h;
@@ -1263,15 +1281,18 @@ void gGridView::setRowCount(int vl)
 	
 	render->setRowCount(vl);
 	
-	h = minRowHeight(vl - 1);
-	render->doNotInvalidate = true;
-	for (i = old; i < vl; i++)
+	if (vl)
 	{
-		//if ((i % 1000) == 0)
-		//	fprintf(stderr, "%d\r", i);
-		setRowHeight(i, h);
+		h = minRowHeight(vl - 1);
+		render->doNotInvalidate = true;
+		for (i = old; i < vl; i++)
+		{
+			//if ((i % 1000) == 0)
+			//	fprintf(stderr, "%d\r", i);
+			setRowHeight(i, h);
+		}
+		render->doNotInvalidate = false;
 	}
-	render->doNotInvalidate = false;
 	
 	unlock();
 	
@@ -1392,7 +1413,7 @@ void gGridView::setColumnWidth(int index,int vl)
 
 int gGridView::minRowHeight(int index)
 {
-	return 8 + font()->height(rowText(index));
+	return 8 + font()->height(" "); // rowText(index)
 }
 
 void gGridView::setRowHeight(int index,int vl)
@@ -1887,6 +1908,11 @@ void gGridView::updateLastColumn()
 	
 	if (n < 0)
 		return;
+		
+	if (_updating_last_column)
+		return;
+		
+	_updating_last_column = true;
 	
 	if (!_last_col_width)
 		_last_col_width = columnWidth(n);
@@ -1898,6 +1924,8 @@ void gGridView::updateLastColumn()
 		//fprintf(stderr, "updateLastColumn: vw = %d -> %d\n", vw, vw - columnPos(n));
 		setColumnWidth(n, vw - columnPos(n));
 	}
+
+	_updating_last_column = false;
 }
 
 void gGridView::startScrollTimer(GSourceFunc func)
