@@ -89,16 +89,24 @@ static gboolean resize_later(gMainWindow *data)
 	return false;
 }
 
-static gboolean cb_configure(GtkWidget *widget,GdkEventConfigure *event,gMainWindow *data)
+static gboolean cb_configure(GtkWidget *widget, GdkEventConfigure *event, gMainWindow *data)
 {
+	gint x, y;
 	//fprintf(stderr, "cb_configure: %p\n", data);
 	
 	if (data->opened)
 	{
-		if ( (event->x!=data->bufX) || (event->y!=data->bufY) )
+		if (data->isTopLevel())
+			gtk_window_get_position(GTK_WINDOW(data->border), &x, &y);
+		else
 		{
-			data->bufX=event->x;
-			data->bufY=event->y;
+			x = event->x;
+			y = event->y;
+		}
+		if (x != data->bufX || y != data->bufY)
+		{
+			data->bufX = x;
+			data->bufY = y;
 			if (data->onMove) data->onMove(data);
 		}
 		
@@ -179,6 +187,8 @@ void gMainWindow::initialize()
 	_current = NULL;
 	_background = NULL;
 	_style = NULL;
+	_next_timer = 0;
+	_xembed = false;
 
 	onOpen = NULL;
 	onShow = NULL;
@@ -206,18 +216,27 @@ void gMainWindow::initWindow()
 	}
 	else
 	{
-		gtk_widget_add_events(widget,GDK_BUTTON_MOTION_MASK);
-		
 		//g_signal_connect(G_OBJECT(border),"size-request",G_CALLBACK(cb_realize),(gpointer)this);
 		g_signal_connect(G_OBJECT(border), "show",G_CALLBACK(cb_show),(gpointer)this);
 		g_signal_connect(G_OBJECT(border), "hide",G_CALLBACK(cb_hide),(gpointer)this);
 		g_signal_connect(G_OBJECT(border), "configure-event",G_CALLBACK(cb_configure),(gpointer)this);
 		g_signal_connect(G_OBJECT(border), "delete-event",G_CALLBACK(win_close),(gpointer)this);
 		g_signal_connect(G_OBJECT(border), "window-state-event",G_CALLBACK(win_frame),(gpointer)this);
+		
+		gtk_widget_add_events(widget,GDK_BUTTON_MOTION_MASK);
 		g_signal_connect(G_OBJECT(widget), "expose-event", G_CALLBACK(cb_expose), (gpointer)this);
 	}
 	
+	//GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
+	//gtk_widget_add_events(widget, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
+	
+	/*	GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK
+		| GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+		| GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK | GDK_POINTER_MOTION_MASK);*/
+
 	gtk_window_add_accel_group(GTK_WINDOW(topLevel()->border), accel);
+
+	have_cursor = parent() == 0 && !_xembed;
 }
 
 gMainWindow::gMainWindow(int plug) : gContainer(NULL)
@@ -227,20 +246,19 @@ gMainWindow::gMainWindow(int plug) : gContainer(NULL)
 	
 	windows = g_list_append(windows, (gpointer)this);
 	
-	if (plug)
+	_xembed = plug != 0;
+	
+	if (_xembed)
 		border = gtk_plug_new(plug);
 	else
-	{
 		border = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		have_cursor = true;
-	}
 	
 	widget = gtk_layout_new(0,0);
 	
-	initWindow();
 	realize(false);
-	gtk_widget_realize(border);
+	initWindow();
 	
+	gtk_widget_realize(border);
 	gtk_widget_show(widget);
 	
 	gtk_widget_set_size_request(border, 4, 4);
@@ -331,16 +349,19 @@ void gMainWindow::setRealBackground(gColor color)
 
 void gMainWindow::move(int x, int y)
 {
-	if ((x == bufX) && (y == bufY)) 
-		return;
+	if (isTopLevel())
+	{
+		if (x == bufX && y == bufY) 
+			return;
 	
-	if (parent())
+		bufX = x;
+		bufY = y;
+		gtk_window_move(GTK_WINDOW(border), x, y);
+	}
+	else
 	{
 		gContainer::move(x,y);
-		return;
 	}
-
-	gtk_window_move(GTK_WINDOW(border), x, y);
 }
 
 
@@ -397,7 +418,7 @@ void gMainWindow::setVisible(bool vl)
 		if (!opened)
 			return;
 		
-		if (isTopLevel())
+		if (isTopLevel() && !_xembed)
 		{
 			group = _current_group;
 			if (!group)
@@ -408,7 +429,6 @@ void gMainWindow::setVisible(bool vl)
 		}
 			
 		_not_spontaneous = !visible;
-			
 		visible = true;
 		
 		if (isTopLevel())
@@ -866,48 +886,6 @@ bool gMainWindow::close()
 	return doClose();
 }
 
-void gMainWindow::reparent(gContainer *newpr, int x, int y)
-{
-	GtkWidget *new_border;
-	bool again = false;
-	
-	//fprintf(stderr, "reparent: %p (%p -> %p)\n", this, parent(), newpr);
-
-
-	if (!parent() && newpr)
-	{
-		gtk_window_remove_accel_group(GTK_WINDOW(topLevel()->border), accel);
-		new_border = gtk_event_box_new();
-		gtk_widget_reparent(widget, new_border);
-		_no_delete = true;
-		gtk_widget_destroy(border);
-		_no_delete = false;
-		border = new_border;
-		again = true;
-	}
-	else if (parent() && !newpr)
-	{
-		gtk_window_remove_accel_group(GTK_WINDOW(topLevel()->border), accel);
-		// TODO: test that
-		new_border = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		gtk_widget_reparent(widget, new_border);
-		_no_delete = true;
-		gtk_widget_destroy(border);
-		_no_delete = false;
-		border = new_border;
-		again = true;
-	}
-	
-	gControl::reparent(newpr, x, y);
-	
-	if (again)
-	{
-		initWindow();	
-		initSignals();
-	}
-}
-
-
 int gMainWindow::controlCount()
 {
 	GList *list = gControl::controlList();
@@ -1026,3 +1004,57 @@ void gMainWindow::setToolBox(bool vl)
 	
 	stub("gMainWindow::setToolBox");
 }
+
+void gMainWindow::reparent(gContainer *newpr, int x, int y)
+{
+	GtkWidget *new_border;
+	int w, h;
+	
+	if (_xembed)
+		return;
+	
+	if (!parent() && newpr)
+	{
+		gtk_window_remove_accel_group(GTK_WINDOW(topLevel()->border), accel);
+		
+		new_border = gtk_event_box_new();
+		gtk_widget_reparent(widget, new_border);
+		_no_delete = true;
+		gtk_widget_destroy(border);
+		_no_delete = false;
+		border = new_border;
+		
+		setParent(newpr);
+		connectParent();
+		borderSignals();
+		initWindow();	
+		
+		move(x, y);
+		gtk_widget_set_size_request(border, width(), height());
+	}
+	else if (parent() && !newpr)
+	{
+		gtk_window_remove_accel_group(GTK_WINDOW(topLevel()->border), accel);
+		// TODO: test that
+		new_border = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		gtk_widget_reparent(widget, new_border);
+		_no_delete = true;
+		gtk_widget_destroy(border);
+		_no_delete = false;
+		border = new_border;
+		
+		parent()->remove(this);
+		parent()->arrange();
+		setParent(NULL);
+		initWindow();	
+		borderSignals();
+		
+		move(x, y);
+		w = width();
+		h = height();
+		bufW = bufH = -1;
+		resize(w, h);
+	}
+	else
+		gControl::reparent(newpr, x, y);	
+}
