@@ -38,22 +38,39 @@ gPicture
 
 ******************************************************************/
 
-static bool pixbufFromMemory(GdkPixbuf **img,char *addr,unsigned int len, bool *trans)
+#define LOAD_INC 65536L
+
+static bool pixbufFromMemory(GdkPixbuf **img, char *addr, unsigned int len, bool *trans)
 {
 	GdkPixbufLoader* loader;
+	GError *error = NULL;
+	gsize size;
 
   *img = 0;
 
-	loader=gdk_pixbuf_loader_new();
-	if (!gdk_pixbuf_loader_write(loader,(guchar*)addr,(gsize)len,NULL)){
-		 g_object_unref(G_OBJECT(loader));
-		 return false;
+	loader = gdk_pixbuf_loader_new();
+	
+	while (len > 0)
+	{
+		size = len > LOAD_INC ? LOAD_INC : len;
+		if (!gdk_pixbuf_loader_write(loader,(guchar*)addr,size, &error))
+		{
+			//g_debug("ERROR: %s", error->message);
+			goto __ERROR;
+		}
+		addr += size;
+		len -= size;
 	}
-	gdk_pixbuf_loader_close(loader,NULL);
-	(*img)=gdk_pixbuf_loader_get_pixbuf(loader);
+	
+	if (!gdk_pixbuf_loader_close(loader, &error))
+	{
+		//g_debug("ERROR: %s", error->message);
+		goto __ERROR;
+	}
+	
+	(*img) = gdk_pixbuf_loader_get_pixbuf(loader);
 	g_object_ref(G_OBJECT(*img));
-	g_object_unref(G_OBJECT(loader));
-
+	
 	if (gdk_pixbuf_get_n_channels(*img) == 3)
 	{
 		// BM: convert to 4 bytes per pixels
@@ -67,7 +84,12 @@ static bool pixbufFromMemory(GdkPixbuf **img,char *addr,unsigned int len, bool *
 	else
 		*trans = true;
 
+	g_object_unref(G_OBJECT(loader));
 	return true;
+	
+__ERROR:
+	g_object_unref(G_OBJECT(loader));
+	return false;
 }
 
 /*static void render_pixbuf(gPicture *pic, GdkPixbuf *img)
@@ -365,12 +387,12 @@ void gPicture::fill(gColor col)
 
 // returns -> 0, OK / -1, Bad format / -2 invalid path
 
-int gPicture::save(char *path, int quality)
+int gPicture::save(const char *path, int quality)
 {
 	bool ok=false;
 	int b;
 	char *type;
-	char *buf=NULL;
+	const char *buf=NULL;
 	GSList *formats = gdk_pixbuf_get_formats();
 	GSList *iter=formats;
 	GdkPixbuf *image = getPixbuf();
@@ -406,9 +428,9 @@ int gPicture::save(char *path, int quality)
 	}
 
 	if (quality >= 0)
-		b = gdk_pixbuf_save(image, path, type, NULL, "quality", quality, NULL);
+		b = gdk_pixbuf_save(image, path, type, NULL, "quality", quality, (void *)NULL);
 	else
-		b = gdk_pixbuf_save(image, path, type, NULL, NULL);
+		b = gdk_pixbuf_save(image, path, type, NULL, (void *)NULL);
 
 
 	if (ok) {
@@ -456,36 +478,37 @@ int gPicture::save(char *path, int quality)
  The following function tries to load an icon from predefined system
  paths
  ***********************************************************************/
-gPicture* gPicture::fromNamedIcon(char *name, int len)
+gPicture* gPicture::fromNamedIcon(const char *name, int len)
 {
 	GtkIconTheme* theme;
 	GdkPixbuf *buf;
 	gPicture *pic=NULL;
 	int r_type=32;
-	char *r_name;
+	char *c_name, *r_name;
 	
 	if (len < 0) len = strlen(name);
-	name = g_strndup(name, len);
+	
+	c_name = g_strndup(name, len);
+	r_name = strchr(c_name, '/');
 
-	r_name=strchr(name, '/');
-
-	if (!r_name) { r_name=name; }
+	if (!r_name)
+		r_name = c_name;
 	else
 	{
-		r_name[0]=0; r_name++;
-		if      (!strcasecmp(name,"menu"))         r_type=8;
-		else if (!strcasecmp(name,"smalltoolbar")) r_type=16;
-		else if (!strcasecmp(name,"largetoolbar")) r_type=32;
-		else if (!strcasecmp(name,"button"))       r_type=16;
-		else if (!strcasecmp(name,"dnd"))          r_type=32;
-		else if (!strcasecmp(name,"dialog"))       r_type=48;
-		else { r_name--; r_name[0]='/'; g_free(name); return NULL; }
+		r_name[0] = 0; r_name++;
+		if      (!strcasecmp(c_name,"menu"))         r_type=8;
+		else if (!strcasecmp(c_name,"smalltoolbar")) r_type=16;
+		else if (!strcasecmp(c_name,"largetoolbar")) r_type=32;
+		else if (!strcasecmp(c_name,"button"))       r_type=16;
+		else if (!strcasecmp(c_name,"dnd"))          r_type=32;
+		else if (!strcasecmp(c_name,"dialog"))       r_type=48;
+		else { r_name--; r_name[0]='/'; g_free(c_name); return NULL; }
 	}
 
 
 	theme=gtk_icon_theme_get_default();
 	buf=gtk_icon_theme_load_icon(theme,r_name,r_type,GTK_ICON_LOOKUP_USE_BUILTIN,NULL);
-	g_free(name);
+	g_free(c_name);
 	if (!buf) return NULL;
 
 	pic=gPicture::fromPixbuf(buf);
@@ -713,16 +736,45 @@ void gPicture::replace(gColor src, gColor dst, bool noteq)
 gPicture* gPicture::flip(bool mirror)
 {
 	gPicture *ret;
-	GdkPixbuf *old;
+	guint32 *src, *dst;
+	int w, h;
+	register guint32 *s, *d;
+	register int x, y;
+	int rowstride;
 
+	getPixbuf();
 	ret = copy();
 	
 	if (!isVoid())
 	{
-    ret->getPixbuf();
-    old = ret->img;
-    ret->img = gdk_pixbuf_flip(old, !mirror);
-    g_object_unref(G_OBJECT(old));
+		src = (guint32 *)data();
+		dst = (guint32 *)ret->data();
+		w = width();
+		h = height();
+		
+		rowstride = gdk_pixbuf_get_rowstride(getPixbuf()) / sizeof(guint32);
+	
+		if (!mirror)
+		{
+			for (y = 0; y < h; y++)
+			{
+				s = src + y * rowstride;
+				d = dst + y * rowstride + w;
+				for (x = 0; x < w; x++)
+					*--d = *s++;
+			}
+		}
+		else
+		{
+			s = src;
+			d = dst + h * rowstride;
+			for (y = 0; y < h; y++)
+			{
+				d -= rowstride;
+				memcpy(d, s, w * sizeof(guint32));
+				s += rowstride;
+			}
+		}
   }
   
 	return ret;
@@ -948,7 +1000,7 @@ void gPictureCache::exit()
   g_hash_table_destroy(cache);
 }
 
-void gPictureCache::put(char *key, gPicture *pic)
+void gPictureCache::put(const char *key, gPicture *pic)
 {
 	if (!key || !*key) return;
   
@@ -957,7 +1009,7 @@ void gPictureCache::put(char *key, gPicture *pic)
 	g_hash_table_replace(cache, (gpointer)g_strdup(key), (gpointer)pic);
 }
 
-gPicture *gPictureCache::get(char *key)
+gPicture *gPictureCache::get(const char *key)
 {
 	if (!key || !*key) return 0;
 	
