@@ -108,11 +108,9 @@ gboolean gcb_keypress (GtkWidget *widget, GdkEventKey *event, gControl *data)
 	
 	if (!gApplication::userEvents()) return false;
 	
-	if (!gKey::enable(widget, event))
-	{
-		if (data->onKeyEvent) 
-			vl = data->onKeyEvent(data,gEvent_KeyPress);
-	}
+	gKey::enable(widget, event);
+	if (data->onKeyEvent) 
+		vl = data->onKeyEvent(data,gEvent_KeyPress);
 	gKey::disable();
 	
 	if (vl)
@@ -146,7 +144,7 @@ gboolean gcb_keyrelease (GtkWidget *widget, GdkEventKey *event, gControl *data)
 	
 	gKey::enable(widget, event);
 	if (data->onKeyEvent) 
-	data->onKeyEvent(data,gEvent_KeyRelease);
+		data->onKeyEvent(data,gEvent_KeyRelease);
 	gKey::disable();
 	
 	if (event->keyval == GDK_Escape)
@@ -165,7 +163,7 @@ gboolean gcb_keyrelease (GtkWidget *widget, GdkEventKey *event, gControl *data)
 	return false;
 }
 
-static gboolean sg_button_Press (GtkWidget *widget,GdkEventButton *event,gControl *data)
+gboolean gcb_button_press(GtkWidget *widget,GdkEventButton *event,gControl *data)
 {
 	if (!gApplication::userEvents()) return false;
 
@@ -216,7 +214,7 @@ static gboolean sg_menu(GtkWidget *widget, gControl *data)
 		return false;
 }
 
-static gboolean sg_button_Release (GtkWidget *widget,GdkEventButton *event,gControl *data)
+gboolean gcb_button_release(GtkWidget *widget,GdkEventButton *event,gControl *data)
 {	
 	if (!gApplication::userEvents()) return false;
 
@@ -444,39 +442,7 @@ static void cb_show(GtkWidget *widget, gContainer *data)
 	data->performArrange();
 }
 
-void gControl::widgetSignals()
-{
-	
-	if (border != widget && !GTK_IS_SCROLLED_WINDOW(border))
-	{
-		g_signal_connect(G_OBJECT(border),"button-release-event",G_CALLBACK(sg_button_Release),(gpointer)this);
-		g_signal_connect(G_OBJECT(border),"button-press-event",G_CALLBACK(sg_button_Press),(gpointer)this);
-		g_signal_connect(G_OBJECT(border),"popup-menu",G_CALLBACK(sg_menu),(gpointer)this);	
-		g_signal_connect_after(G_OBJECT(border),"motion-notify-event",G_CALLBACK(sg_motion),(gpointer)this);
-		g_signal_connect(G_OBJECT(border),"scroll-event",G_CALLBACK(sg_scroll),(gpointer)this);
-		g_signal_connect(G_OBJECT(border),"key-press-event",G_CALLBACK(gcb_keypress),(gpointer)this);
-		g_signal_connect(G_OBJECT(border),"key-release-event",G_CALLBACK(gcb_keyrelease),(gpointer)this);
-	}
-	else
-	{
-		g_signal_connect(G_OBJECT(widget),"scroll-event",G_CALLBACK(sg_scroll),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"button-release-event",G_CALLBACK(sg_button_Release),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"button-press-event",G_CALLBACK(sg_button_Press),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"motion-notify-event",G_CALLBACK(sg_motion),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"popup-menu",G_CALLBACK(sg_menu),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"key-press-event",G_CALLBACK(gcb_keypress),(gpointer)this);
-		g_signal_connect(G_OBJECT(widget),"key-release-event",G_CALLBACK(gcb_keyrelease),(gpointer)this);
-	}	
-	
-	g_signal_connect(G_OBJECT(widget),"focus-in-event",G_CALLBACK(sg_focus_In),(gpointer)this);
-	g_signal_connect(G_OBJECT(widget),"focus-out-event",G_CALLBACK(sg_focus_Out),(gpointer)this);
-	g_signal_connect(G_OBJECT(widget),"event",G_CALLBACK(sg_event),(gpointer)this);
-	
-	if (isContainer())
-		g_signal_connect(G_OBJECT(border), "show", G_CALLBACK(cb_show), (gpointer)this);
-}
-
-void gControl::initSignals()
+void gControl::borderSignals()
 {	
 	g_signal_connect(G_OBJECT(border),"destroy",G_CALLBACK(sg_destroy),(gpointer)this);
 	//g_signal_connect(G_OBJECT(border),"drag-data-received",G_CALLBACK(sg_drag_data_received),(gpointer)this);
@@ -490,5 +456,45 @@ void gControl::initSignals()
 	
 	//g_signal_connect_after(G_OBJECT(border),"size-allocate",G_CALLBACK(sg_size),(gpointer)this);
 	
+	if (isContainer())
+		g_signal_connect(G_OBJECT(border), "show", G_CALLBACK(cb_show), (gpointer)this);
+
+	if (border != widget && !GTK_IS_SCROLLED_WINDOW(border))
+	{
+		if (!_no_default_mouse_event)
+		{
+			g_signal_connect(G_OBJECT(border),"button-release-event",G_CALLBACK(gcb_button_release),(gpointer)this);
+			g_signal_connect(G_OBJECT(border),"button-press-event",G_CALLBACK(gcb_button_press),(gpointer)this);
+		}
+		g_signal_connect(G_OBJECT(border),"popup-menu",G_CALLBACK(sg_menu),(gpointer)this);	
+		g_signal_connect_after(G_OBJECT(border),"motion-notify-event",G_CALLBACK(sg_motion),(gpointer)this);
+		g_signal_connect(G_OBJECT(border),"scroll-event",G_CALLBACK(sg_scroll),(gpointer)this);
+	}
+}
+
+void gControl::widgetSignals()
+{
+	if (!(border != widget && !GTK_IS_SCROLLED_WINDOW(border)))
+	{
+		g_signal_connect(G_OBJECT(widget),"scroll-event",G_CALLBACK(sg_scroll),(gpointer)this);
+		if (!_no_default_mouse_event)
+		{
+			g_signal_connect(G_OBJECT(widget),"button-release-event",G_CALLBACK(gcb_button_release),(gpointer)this);
+			g_signal_connect(G_OBJECT(widget),"button-press-event",G_CALLBACK(gcb_button_press),(gpointer)this);
+		}
+		g_signal_connect(G_OBJECT(widget),"motion-notify-event",G_CALLBACK(sg_motion),(gpointer)this);
+		g_signal_connect(G_OBJECT(widget),"popup-menu",G_CALLBACK(sg_menu),(gpointer)this);
+	}	
+	
+	g_signal_connect(G_OBJECT(widget),"key-press-event",G_CALLBACK(gcb_keypress),(gpointer)this);
+	g_signal_connect(G_OBJECT(widget),"key-release-event",G_CALLBACK(gcb_keyrelease),(gpointer)this);
+	g_signal_connect(G_OBJECT(widget),"focus-in-event",G_CALLBACK(sg_focus_In),(gpointer)this);
+	g_signal_connect(G_OBJECT(widget),"focus-out-event",G_CALLBACK(sg_focus_Out),(gpointer)this);
+	g_signal_connect(G_OBJECT(widget),"event",G_CALLBACK(sg_event),(gpointer)this);
+}
+
+void gControl::initSignals()
+{	
+	borderSignals();
 	widgetSignals();
 }
