@@ -82,6 +82,7 @@ gTextArea::gTextArea(gContainer *parent) : gControl(parent)
 	
 	have_cursor = true;
 	use_base = true;
+	no_input_method = true;
 	
 	onChange = 0;
 	onCursor = 0;
@@ -127,7 +128,7 @@ char* gTextArea::text()
 	return gtk_text_buffer_get_text(buf,&start,&end,true);
 }
 
-void gTextArea::setText(char *txt)
+void gTextArea::setText(const char *txt)
 {
 	GtkTextBuffer *buf=gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
 	if (!txt) txt="";
@@ -309,7 +310,7 @@ void gTextArea::paste()
 	
 }
 
-void gTextArea::insert(char *txt)
+void gTextArea::insert(const char *txt)
 {
 	GtkTextBuffer *buf=gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
 	if (!txt) txt="";
@@ -400,7 +401,7 @@ char* gTextArea::selText()
 	return gtk_text_buffer_get_text(buf,&start,&end,true);
 }
 
-void gTextArea::setSelText(char *vl)
+void gTextArea::setSelText(const char *vl)
 {
 	GtkTextBuffer *buf=gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
 	GtkTextIter start,end;
