@@ -30,10 +30,13 @@
 #define __MAIN_H
 
 #include "gambas.h"
+#include "widgets.h"
+#include "CWidget.h"
 
 #ifndef __MAIN_C
 extern GB_INTERFACE GB;
 #endif
-void do_iteration();
+
+void do_iteration(bool do_not_block);
 #endif
 
