@@ -4,7 +4,7 @@
 
   Network component
 
-  (c) 2003-2004 Daniel Campos Fernández <danielcampos@netcourrier.com>
+  (c) 2003-2004 Daniel Campos Fernández <dcamposf@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,6 +62,7 @@ GB_STREAM_DESC SerialStream = {
 	handle: CSerialPort_stream_handle
 };
 
+
 DECLARE_EVENT (Serial_Read);
 DECLARE_EVENT (Serial_DTR);
 DECLARE_EVENT (Serial_DSR);
@@ -111,7 +112,7 @@ void CSerialPort_CallBack(long lParam)
 	struct pollfd mypoll;
 	int numpoll;
 	CSERIALPORT *mythis;
-	/*	Just sleeping a little to reduce CPU waste	*/
+	/*	Just sleeping a bit to reduce CPU waste	*/
 	struct timespec mywait;
 	mywait.tv_sec=0;
 	mywait.tv_nsec=1000000;
@@ -224,11 +225,11 @@ int CSerialPort_stream_open(GB_STREAM *stream, const char *path, int mode, void
 {
 	return -1; /* not allowed */
 }
-int CSerialPort_stream_seek(GB_STREAM *stream, long long pos, int whence)
+int CSerialPort_stream_seek(GB_STREAM *stream, int64_t pos, int whence)
 {
 	return -1; /* not allowed */
 }
-int CSerialPort_stream_tell(GB_STREAM *stream, long long *pos)
+int CSerialPort_stream_tell(GB_STREAM *stream, int64_t *pos)
 {
 	return -1; /* not allowed */
 }
@@ -242,74 +243,74 @@ int CSerialPort_stream_handle(GB_STREAM *stream)
 }
 int CSerialPort_stream_close(GB_STREAM *stream)
 {
-	CSERIALPORT *mythis;
+	void *_object=((void**)stream->_free)[0];
 
-	if (!(mythis=(CSERIALPORT*)stream->_free[0])) return -1;	
+	if (!_object) return -1;	
 	
-	if (mythis->iStatus)
+	if (THIS->iStatus)
 	{
-		CSerialPort_FreeCallBack((long)mythis);
-		mythis->stream.desc=NULL;
-		CloseSerialPort(mythis->Port,&mythis->oldtio);
-		mythis->iStatus=0;
+		CSerialPort_FreeCallBack((long)THIS);
+		THIS->stream.desc=NULL;
+		CloseSerialPort(THIS->Port,&THIS->oldtio);
+		THIS->iStatus=0;
 	}
 	return 0;
 }
-int CSerialPort_stream_lof(GB_STREAM *stream, long long *len)
+int CSerialPort_stream_lof(GB_STREAM *stream, int64_t *len)
 {
-	CSERIALPORT *mythis;
+	void *_object=((void**)stream->_free)[0];
 	int bytes;
 
 	*len=0;
-	if (!(mythis=(CSERIALPORT*)stream->_free[0])) return -1;
+	if (!_object) return -1;
 	
-	if (ioctl(mythis->Port,FIONREAD,&bytes)) return -1;
+	if (ioctl(THIS->Port,FIONREAD,&bytes)) return -1;
 	*len=bytes;
 	return 0;
 }
 int CSerialPort_stream_eof(GB_STREAM *stream)
 {
-	CSERIALPORT *mythis;
+	void *_object=((void**)stream->_free)[0];
 	int bytes;
 
-	if (!(mythis=(CSERIALPORT*)stream->_free[0])) return -1;
+	if (!_object) return -1;
 	
-	if (ioctl(mythis->Port,FIONREAD,&bytes)) return -1;
+	if (ioctl(THIS->Port,FIONREAD,&bytes)) return -1;
 	if (!bytes) return -1;
 	return 0;
 }
 
-int CSerialPort_stream_read(GB_STREAM *stream, char *buffer, long len)
+int CSerialPort_stream_read(GB_STREAM *stream, char *buffer, int len)
 {
-	CSERIALPORT *mythis;
+	void *_object=((void**)stream->_free)[0];
   	int npos=-1;
   	int NoBlock=0;
 	int bytes;
 
-  	if (!(mythis=(CSERIALPORT*)stream->_free[0])) return -1;
+  	if (!_object) return -1;
 	
-	if (ioctl(mythis->Port,FIONREAD,&bytes)) return -1;
+	if (ioctl(THIS->Port,FIONREAD,&bytes)) return -1;
 	if (bytes < len) return -1;
-	ioctl(mythis->Port,FIONBIO,&NoBlock);
-	npos=read(mythis->Port,(void*)buffer,len);
+	ioctl(THIS->Port,FIONBIO,&NoBlock);
+	npos=read(THIS->Port,(void*)buffer,len);
 	NoBlock++;
-  	ioctl(mythis->Port,FIONBIO,&NoBlock);
+  	ioctl(THIS->Port,FIONBIO,&NoBlock);
   	if (npos==len) return 0;
   	return -1;
 }
 
-int CSerialPort_stream_write(GB_STREAM *stream, char *buffer, long len)
+int CSerialPort_stream_write(GB_STREAM *stream, char *buffer, int len)
 {
-	CSERIALPORT *mythis;
+	void *_object=((void**)stream->_free)[0];
 	int npos=-1;
 	int NoBlock=0;
 
-	if (!(mythis=(CSERIALPORT*)stream->_free[0])) return -1;
+	if (!_object) return -1;
 	
-	ioctl(mythis->Port,FIONBIO,&NoBlock);
-	npos=write(mythis->Port,(void*)buffer,len);
+	ioctl(THIS->Port,FIONBIO,&NoBlock);
+	npos=write(THIS->Port,(void*)buffer,len);
 	NoBlock++;
-	ioctl(mythis->Port,FIONBIO,&NoBlock);
+	ioctl(THIS->Port,FIONBIO,&NoBlock);
 	if (npos>=0) return 0;
 	return -1;
 }
@@ -620,17 +621,17 @@ END_PROPERTY
  *************************************************/
 BEGIN_METHOD_VOID(CSERIALPORT_new)
 
-  THIS->stream.desc=NULL;
-  THIS->Port=0;
-  THIS->iStatus=0;
-  THIS->sPort=NULL;
-  GB.NewString(&THIS->sPort,"/dev/ttyS0",10);
-  THIS->Speed=19200;
-  THIS->Parity=0;
-  THIS->DataBits=8;
-  THIS->StopBits=1;
-  THIS->iFlow=1;
-
+	((void**)THIS->stream._free)[0]=_object;
+	THIS->stream.desc=NULL;
+	THIS->Port=0;
+	THIS->iStatus=0;
+	THIS->sPort=NULL;
+	GB.NewString(&THIS->sPort,"/dev/ttyS0",10);
+	THIS->Speed=19200;
+	THIS->Parity=0;
+	THIS->DataBits=8;
+	THIS->StopBits=1;
+	THIS->iFlow=1;
 
 END_METHOD
 
@@ -682,7 +683,6 @@ BEGIN_METHOD_VOID(CSERIALPORT_Open)
 	CSerialPort_AssignCallBack((long)THIS,THIS->Port);
 	//CSerialPort_stream_init(&THIS->stream,THIS->Port);
 	THIS->stream.desc=&SerialStream;
-	THIS->stream._free[0]=(long)THIS;
 	THIS->iStatus=1;
 
 
