@@ -4,7 +4,7 @@
 
   Network component
 
-  (c) 2003-2004 Daniel Campos Fernández <danielcampos@netcourrier.com>
+  (c) 2003-2004 Daniel Campos Fernández <dcamposf@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,6 +53,7 @@ GB_STREAM_DESC UdpSocketStream = {
 	handle: CUdpSocket_stream_handle
 };
 
+
 DECLARE_EVENT (CUDPSOCKET_Read);
 DECLARE_EVENT (CUDPSOCKET_SocketError);
 
@@ -61,14 +62,14 @@ void CUdpSocket_post_data(long Param)
 	CUDPSOCKET *t_obj;
 	t_obj=(CUDPSOCKET*)Param;
 	GB.Raise(t_obj,CUDPSOCKET_Read,0);
-	GB.Unref((void**)&t_obj);
+	GB.Unref(POINTER(&t_obj));
 }
 void CUdpSocket_post_error(long Param)
 {
 	CUDPSOCKET *t_obj;
 	t_obj=(CUDPSOCKET*)Param;
 	GB.Raise(t_obj,CUDPSOCKET_SocketError,0);
-	GB.Unref((void**)&t_obj);
+	GB.Unref(POINTER(&t_obj));
 }
 
 void CUdpSocket_CallBack(int t_sock,int type,long param)
@@ -76,7 +77,7 @@ void CUdpSocket_CallBack(int t_sock,int type,long param)
 	char buf[1];
 	int numpoll;
 	struct sockaddr_in t_test;
-	int t_test_len;
+	unsigned int t_test_len;
 	struct timespec mywait;
 	CUDPSOCKET *t_obj;
 
@@ -91,7 +92,7 @@ void CUdpSocket_CallBack(int t_sock,int type,long param)
 	t_test.sin_port=0;
 	t_test_len=sizeof(struct sockaddr);
 
-	USE_MSG_NOSIGNAL(numpoll=recvfrom(t_sock,(void*)buf, sizeof(char), MSG_PEEK | MSG_NOSIGNAL \
+	USE_MSG_NOSIGNAL(numpoll=recvfrom(t_sock,POINTER(buf), sizeof(char), MSG_PEEK | MSG_NOSIGNAL \
 		              , (struct sockaddr*)&t_test, &t_test_len));
 	if (t_test.sin_port)
 	{
@@ -101,8 +102,8 @@ void CUdpSocket_CallBack(int t_sock,int type,long param)
 }
 /* not allowed methods */
 int CUdpSocket_stream_open(GB_STREAM *stream, const char *path, int mode, void *data){return -1;}
-int CUdpSocket_stream_seek(GB_STREAM *stream, long long pos, int whence){return -1;}
-int CUdpSocket_stream_tell(GB_STREAM *stream, long long *pos)
+int CUdpSocket_stream_seek(GB_STREAM *stream, int64_t pos, int whence){return -1;}
+int CUdpSocket_stream_tell(GB_STREAM *stream, int64_t *pos)
 {
 	*pos=0;
 	return -1; /* not allowed */
@@ -117,35 +118,35 @@ int CUdpSocket_stream_handle(GB_STREAM *stream)
 }
 int CUdpSocket_stream_close(GB_STREAM *stream)
 {
-	CUDPSOCKET *mythis;
+	void *_object=((void**)stream->_free)[0];
 
-	if ( !(mythis=(CUDPSOCKET*)stream->_free[0]) ) return -1;
+	if ( !_object ) return -1;
 	stream->desc=NULL;
-	if (mythis->iStatus > 0)
+	if (THIS->iStatus > 0)
 	{
-		GB.Watch (mythis->Socket,GB_WATCH_NONE,(void *)CUdpSocket_CallBack,(long)mythis);
-		close(mythis->Socket);
-		mythis->iStatus=0;
+		GB.Watch (THIS->Socket,GB_WATCH_NONE,(void *)CUdpSocket_CallBack,(long)THIS);
+		close(THIS->Socket);
+		THIS->iStatus=0;
 	}
-	if (mythis->shost) GB.FreeString(&mythis->shost);
-	if (mythis->thost) GB.FreeString(&mythis->thost);
-	mythis->shost=NULL;
-	mythis->thost=NULL;
-	mythis->sport=0;
-	mythis->tport=0;
-	mythis->iStatus=0;
+	if (THIS->shost) GB.FreeString(&THIS->shost);
+	if (THIS->thost) GB.FreeString(&THIS->thost);
+	THIS->shost=NULL;
+	THIS->thost=NULL;
+	THIS->sport=0;
+	THIS->tport=0;
+	THIS->iStatus=0;
 	return 0;
 }
-int CUdpSocket_stream_lof(GB_STREAM *stream, long long *len)
+int CUdpSocket_stream_lof(GB_STREAM *stream, int64_t *len)
 {
-	CUDPSOCKET *mythis;
+	void *_object=((void**)stream->_free)[0];
 	int bytes;
 
-	if ( !(mythis=(CUDPSOCKET*)stream->_free[0]) ) return -1;
-	if (ioctl(mythis->Socket,FIONREAD,&bytes))
+	if ( !_object ) return -1;
+	if (ioctl(THIS->Socket,FIONREAD,&bytes))
 	{
 		CUdpSocket_stream_close(stream);
-		mythis->iStatus=-4;
+		THIS->iStatus=-4;
 		return -1;
 	}
 	*len=bytes;
@@ -153,14 +154,14 @@ int CUdpSocket_stream_lof(GB_STREAM *stream, long long *len)
 }
 int CUdpSocket_stream_eof(GB_STREAM *stream)
 {
-	CUDPSOCKET *mythis;
+	void *_object=((void**)stream->_free)[0];
 	int bytes;
 
-	if ( !(mythis=(CUDPSOCKET*)stream->_free[0]) ) return -1;
-	if (ioctl(mythis->Socket,FIONREAD,&bytes))
+	if ( !_object ) return -1;
+	if (ioctl(THIS->Socket,FIONREAD,&bytes))
 	{
 		CUdpSocket_stream_close(stream);
-		mythis->iStatus=-4;
+		THIS->iStatus=-4;
 		return -1;
 	}
 	if (!bytes) return -1;
@@ -168,67 +169,67 @@ int CUdpSocket_stream_eof(GB_STREAM *stream)
 
 }
 
-int CUdpSocket_stream_read(GB_STREAM *stream, char *buffer, long len)
+int CUdpSocket_stream_read(GB_STREAM *stream, char *buffer, int len)
 {
-	CUDPSOCKET *mythis;
+	void *_object=((void**)stream->_free)[0];
     	int retval;
 	int bytes=0;
 	int NoBlock=0;
-	int rem_host_len;
+	unsigned int rem_host_len;
 	struct sockaddr_in remhost;
 
 
-	if ( !(mythis=(CUDPSOCKET*)stream->_free[0]) ) return -1;
-	if (ioctl(mythis->Socket,FIONREAD,&bytes))
+	if ( !_object ) return -1;
+	if (ioctl(THIS->Socket,FIONREAD,&bytes))
 	{
 		CUdpSocket_stream_close(stream);
-		mythis->iStatus=-4;
+		THIS->iStatus=-4;
 		return -1;
 	}
 	if (bytes<len) return -1;
 	rem_host_len=sizeof(struct sockaddr);
-	ioctl(mythis->Socket,FIONBIO,&NoBlock);
-	USE_MSG_NOSIGNAL(retval=recvfrom(mythis->Socket,(void*)buffer,len*sizeof(char) \
+	ioctl(THIS->Socket,FIONBIO,&NoBlock);
+	USE_MSG_NOSIGNAL(retval=recvfrom(THIS->Socket,(void*)buffer,len*sizeof(char) \
 	       ,MSG_NOSIGNAL,(struct sockaddr*)&remhost,&rem_host_len));
 	NoBlock++;
-	ioctl(mythis->Socket,FIONBIO,&NoBlock);
+	ioctl(THIS->Socket,FIONBIO,&NoBlock);
 	if (retval<0)
 	{
-		CUdpSocket_stream_close(&mythis->stream);
-		mythis->iStatus=-4;
+		CUdpSocket_stream_close(&THIS->stream);
+		THIS->iStatus=-4;
 		return -1;
 	}
-	mythis->sport=ntohs(remhost.sin_port);
-	GB.FreeString(&mythis->shost);
-	GB.NewString (&mythis->shost , inet_ntoa(remhost.sin_addr) ,0);
+	THIS->sport=ntohs(remhost.sin_port);
+	GB.FreeString(&THIS->shost);
+	GB.NewString (&THIS->shost , inet_ntoa(remhost.sin_addr) ,0);
 	return 0;
 }
 
-int CUdpSocket_stream_write(GB_STREAM *stream, char *buffer, long len)
+int CUdpSocket_stream_write(GB_STREAM *stream, char *buffer, int len)
 {
-	CUDPSOCKET *mythis;
+	void *_object=((void**)stream->_free)[0];
     	int retval;
 	int NoBlock=0;
 	struct sockaddr_in remhost;
 	struct in_addr rem_ip;
 
-	if ( !(mythis=(CUDPSOCKET*)stream->_free[0]) ) return -1;
+	if ( !_object ) return -1;
 
-	if (!mythis->thost) return -1;
-	if ( (mythis->tport<1) || (mythis->tport>65535) ) return -1;
-	if (!inet_aton ( (const char*)mythis->thost,&rem_ip)) return -1;
+	if (!THIS->thost) return -1;
+	if ( (THIS->tport<1) || (THIS->tport>65535) ) return -1;
+	if (!inet_aton ( (const char*)THIS->thost,&rem_ip)) return -1;
 	remhost.sin_family=AF_INET;
-	remhost.sin_port=htons(mythis->tport);
+	remhost.sin_port=htons(THIS->tport);
 	remhost.sin_addr.s_addr=rem_ip.s_addr;
 	bzero(&(remhost.sin_zero),8);
-	ioctl(mythis->Socket,FIONBIO,&NoBlock);
-	USE_MSG_NOSIGNAL(retval=sendto(mythis->Socket,(void*)buffer,len*sizeof(char) \
+	ioctl(THIS->Socket,FIONBIO,&NoBlock);
+	USE_MSG_NOSIGNAL(retval=sendto(THIS->Socket,(void*)buffer,len*sizeof(char) \
 		              ,MSG_NOSIGNAL,(struct sockaddr*)&remhost,sizeof(struct sockaddr)));
 	NoBlock++;
-	ioctl(mythis->Socket,FIONBIO,&NoBlock);
+	ioctl(THIS->Socket,FIONBIO,&NoBlock);
 	if (retval>=0) return 0;
 	CUdpSocket_stream_close(stream);
-	mythis->iStatus= -5;
+	THIS->iStatus= -5;
 	return -1;
 }
 
@@ -294,7 +295,6 @@ static int dgram_start(CUDPSOCKET *mythis,int myport)
 	ioctl(mythis->Socket,FIONBIO,&NoBlock);
 	GB.Watch (mythis->Socket,GB_WATCH_WRITE,(void *)CUdpSocket_CallBack,(long)mythis);
 	mythis->stream.desc=&UdpSocketStream;
-	mythis->stream._free[0]=(long)mythis;
 	return 0;
 }
 
@@ -362,16 +362,9 @@ END_PROPERTY
  *************************************************/
 BEGIN_METHOD(CUDPSOCKET_new,GB_INTEGER Port;)
 
-  /*THIS->iStatus=0;
-  THIS->iPort=0;
-  THIS->shost=NULL;
-  THIS->thost=NULL;
-  THIS->sport=0;
-  THIS->tport=0;*/
-
-  if (MISSING (Port) ) return;
-
-  dgram_start(THIS,VARG(Port));
+	((void**)THIS->stream._free)[0]=_object;
+	if (MISSING (Port) ) return;
+	dgram_start(THIS,VARG(Port));
 
 END_METHOD
 
@@ -389,7 +382,7 @@ BEGIN_METHOD_VOID (CUDPSOCKET_Peek)
 
 	char *sData=NULL;
 	struct sockaddr_in remhost;
-	int rem_host_len;
+	unsigned int rem_host_len;
 	int retval=0;
 	int NoBlock=0;
 	int peeking;
@@ -406,14 +399,14 @@ BEGIN_METHOD_VOID (CUDPSOCKET_Peek)
 	ioctl(THIS->Socket,FIONREAD,&bytes);
 	if (bytes)
 	{
-		GB.Alloc( (void**)&sData,bytes*sizeof(char) );
+		GB.Alloc( POINTER(&sData),bytes*sizeof(char) );
 		rem_host_len=sizeof(struct sockaddr);
 		ioctl(THIS->Socket,FIONBIO,&NoBlock);
 		USE_MSG_NOSIGNAL(retval=recvfrom(THIS->Socket,(void*)sData,1024*sizeof(char) \
 		       ,peeking,(struct sockaddr*)&remhost,&rem_host_len));
 		if (retval<0)
 		{
-			GB.Free((void**)&sData);
+			GB.Free(POINTER(&sData));
 			CUdpSocket_stream_close(&THIS->stream);
 			THIS->iStatus=-4;
 			GB.Raise(THIS,CUDPSOCKET_SocketError,0);
@@ -429,7 +422,7 @@ BEGIN_METHOD_VOID (CUDPSOCKET_Peek)
 			GB.ReturnNewString(sData,retval);
 		else
 			GB.ReturnNewString(NULL,0);
-		GB.Free((void**)&sData);
+		GB.Free(POINTER(&sData));
 	}
 	else
 	{
