@@ -2,9 +2,9 @@
 
   GL.h
 
-  openGL component
+  The Gambas openGL component
 
-  (c) 2005-2006 Laurent Carlier <lordheavy@users.sourceforge.net>
+  (c) 2005-2007 Laurent Carlier <lordheavy@users.sourceforge.net>
                 Benoît Minisini <gambas@users.sourceforge.net>
 
   This program is free software; you can redistribute it and/or modify
