@@ -57,6 +57,8 @@ DECLARE_METHOD(GLMATERIALFV);
 DECLARE_METHOD(GLMATERIALIV);
 DECLARE_METHOD(GLNORMAL3F);
 DECLARE_METHOD(GLNORMAL3I);
+DECLARE_METHOD(GLNORMAL3FV);
+DECLARE_METHOD(GLNORMAL3IV);
 DECLARE_METHOD(GLSHADEMODEL);
 
 #endif /* __GLCOLORLIGHTING_H */
