@@ -72,7 +72,7 @@ BEGIN_METHOD(GLPOLYGONMODE, GB_INTEGER face; GB_INTEGER mode)
 	glPolygonMode(VARG(face), VARG(mode));
 
 END_METHOD
-
+#if 0
 BEGIN_METHOD(GLPOLYGONSTIPPLE, GB_INTEGER mask)
 
 	GLubyte mask[4*32];
@@ -88,7 +88,7 @@ BEGIN_METHOD(GLPOLYGONSTIPPLE, GB_INTEGER mask)
 	glPolygonStipple(mask);
 
 END_METHOD
-
+#endif
 BEGIN_METHOD(GLRASTERPOSF, GB_FLOAT x; GB_FLOAT y; GB_FLOAT z; GB_FLOAT w)
 
 	if (MISSING(z))
