@@ -78,8 +78,10 @@ static void resize_container(QWidget *wid, QWidget *cont, int w, int h)
 #define IS_EXPAND(_object) (((CWIDGET *)_object)->flag.expand)
 #define IS_IGNORE(_object) (((CWIDGET *)_object)->flag.ignore)
 #define IS_DESIGN(_object) (CWIDGET_test_flag(_object, WF_DESIGN) && CWIDGET_test_flag(_object, WF_DESIGN_LEADER))
-
 #define IS_WIDGET_VISIBLE(_widget) (_widget)->isVisible()
+
+#define CAN_ARRANGE(_object) (IS_WIDGET_VISIBLE(GET_CONTAINER(_object)) || IS_WIDGET_VISIBLE(GET_WIDGET(_object)))
+
 #define GET_WIDGET_CONTENTS(_widget, _x, _y, _w, _h) \
 	_x = (_widget)->contentsRect().x(); \
 	_y = (_widget)->contentsRect().y(); \
@@ -188,7 +190,7 @@ static void arrange_later(QWidget *cont)
   GB.Ref(_object);
   //qDebug("later: %p: dirty = TRUE", THIS);
   THIS_ARRANGEMENT->dirty = TRUE;
-  GB.Post((void (*)())post_arrange_later, (long)THIS);
+  GB.Post((void (*)())post_arrange_later, (intptr_t)THIS);
 }
 #endif
 
@@ -230,7 +232,6 @@ void MyContainer::childEvent(QChildEvent *e)
 {
   void *_object = CWidget::get(this);
   void *child;
-  //qDebug("MyContainer::childEvent %p", CWidget::get(this));
   
   QFrame::childEvent(e);
 
@@ -334,7 +335,7 @@ BEGIN_METHOD(CCONTAINER_children_get, GB_INTEGER index)
 	if (index >= 0)
 	{
 		i = 0;
-		for(i = 0; i < list->count(); i++)
+		for(i = 0; i < (int)list->count(); i++)
 		{
 			widget = CWidget::getReal(list->at(i));
 			if (!widget)
@@ -557,13 +558,11 @@ BEGIN_METHOD(CUSERCONTROL_new, GB_OBJECT parent)
 
   MyContainer *wid = new MyContainer(QCONTAINER(VARG(parent)));
 
-  CWIDGET_new(wid, (void *)_object);
-
   THIS->container = wid;
   THIS_ARRANGEMENT->mode = ARRANGE_FILL;
   THIS_ARRANGEMENT->user = true;
 
-  wid->show();
+  CWIDGET_new(wid, (void *)_object);
 
 END_METHOD
 
