@@ -43,7 +43,6 @@
 #include "CMouse.h"
 #define DO_NOT_DECLARE_EVENTS
 #include "CWidget.h"
-#include "trayicon.xpm"
 #include "CTrayIcon.h"
 
 DECLARE_METHOD(CCONTROL_screen_x);
@@ -65,6 +64,7 @@ DECLARE_EVENT(EVENT_Menu);
 static int _state;
 static QList<CTRAYICON> _list;
 
+#include "gb.form.trayicon.h"
 
 static CTRAYICON *find_object(const QObject *o)
 {
@@ -97,14 +97,14 @@ void CTRAYICON_close_all(void)
   QListIterator<CTRAYICON> it(_list);
   CTRAYICON *_object;
 
+  GB.StopAllEnum(GB.FindClass("TrayIcons"));
+  
   while ((_object = it.current()))
   {
     ++it;
     destroy_widget(THIS);
     GB.Unref(POINTER(&_object));
   }
-
-  GB.StopAllEnum(GB.FindClass("TrayIcons"));
 }
 
 
@@ -204,7 +204,8 @@ BEGIN_METHOD_VOID(CTRAYICON_show)
 
   if (!WIDGET)
   {
-    QtXEmbedClient *wid = new QtXEmbedClient(true);
+    QtXEmbedClient *wid = new QtXEmbedClient();
+    wid->setFocusPolicy(QWidget::NoFocus);
 
     THIS->widget = wid;
     wid->installEventFilter(&CTrayIcon::manager);
@@ -312,6 +313,47 @@ BEGIN_PROPERTY(CTRAYICON_count)
 
 END_PROPERTY
 
+BEGIN_PROPERTY(CTRAYICON_screen_x)
+
+	if (WIDGET)
+		CCONTROL_screen_x(_object, _param);
+	else
+		GB.ReturnInteger(0);
+
+END_PROPERTY
+
+
+BEGIN_PROPERTY(CTRAYICON_screen_y)
+
+	if (WIDGET)
+		CCONTROL_screen_y(_object, _param);
+	else
+		GB.ReturnInteger(0);
+
+END_PROPERTY
+
+
+BEGIN_PROPERTY(CTRAYICON_w)
+
+	if (WIDGET)
+		CCONTROL_w(_object, _param);
+	else
+		GB.ReturnInteger(0);
+
+END_PROPERTY
+
+
+BEGIN_PROPERTY(CTRAYICON_h)
+
+	if (WIDGET)
+		CCONTROL_h(_object, _param);
+	else
+		GB.ReturnInteger(0);
+
+END_PROPERTY
+
+
+
 
 GB_DESC CTrayIconsDesc[] =
 {
@@ -344,12 +386,12 @@ GB_DESC CTrayIconDesc[] =
   GB_PROPERTY("Tooltip", "s", CTRAYICON_tooltip),
   GB_PROPERTY("Tag", "v", CTRAYICON_tag),
 
-  GB_PROPERTY_READ("ScreenX", "i", CCONTROL_screen_x),
-  GB_PROPERTY_READ("ScreenY", "i", CCONTROL_screen_y),
-  GB_PROPERTY_READ("Width", "i", CCONTROL_w),
-  GB_PROPERTY_READ("Height", "i", CCONTROL_h),
-  GB_PROPERTY_READ("W", "i", CCONTROL_w),
-  GB_PROPERTY_READ("H", "i", CCONTROL_h),
+  GB_PROPERTY_READ("ScreenX", "i", CTRAYICON_screen_x),
+  GB_PROPERTY_READ("ScreenY", "i", CTRAYICON_screen_y),
+  GB_PROPERTY_READ("Width", "i", CTRAYICON_w),
+  GB_PROPERTY_READ("Height", "i", CTRAYICON_h),
+  GB_PROPERTY_READ("W", "i", CTRAYICON_w),
+  GB_PROPERTY_READ("H", "i", CTRAYICON_h),
 
   GB_EVENT("Enter", NULL, NULL, &EVENT_Enter),
   GB_EVENT("GotFocus", NULL, NULL, &EVENT_GotFocus),
@@ -513,5 +555,8 @@ bool CTrayIcon::eventFilter(QObject *widget, QEvent *event)
 _DESIGN:
 _STANDARD:
 
+	if (!find_object(widget))
+		return true;
+		
   return QObject::eventFilter(widget, event);    // standard event processing
 }
