@@ -234,7 +234,7 @@ void MyListViewItem::cancelRename(int col)
 	if (GB.CanRaise(container, EVENT_Cancel))
 	{
 		GB.Ref(container);
-		GB.Post((GB_POST_FUNC)post_cancel_event, (long)container);
+		GB.Post((GB_POST_FUNC)post_cancel_event, (intptr_t)container);
 	}
 }
 
@@ -246,6 +246,82 @@ void MyListViewItem::cancelRename(int col)
 	QListViewItem::setSelected(s);
 }*/
 
+MyListViewItem *MyListViewItem::previousSibling()
+{
+	MyListViewItem *lwi, *lwn = 0;
+	
+	if (parent())
+		lwi = (MyListViewItem *)parent()->firstChild(); 
+	else
+		lwi = (MyListViewItem *)listView()->firstChild();
+		
+	for (;;)
+	{
+		if (!lwi || lwi == this)
+			break;
+		lwn = lwi;
+		lwi = (MyListViewItem *)lwi->nextSibling();
+	}
+
+	return lwn;
+}
+
+MyListViewItem *MyListViewItem::findAbove()
+{
+	MyListViewItem *key, *key2;
+	
+	key = previousSibling();
+	if (!key)
+		return (MyListViewItem *)parent();
+		
+	for(;;)
+	{
+		key2 = (MyListViewItem *)key->firstChild();
+		if (!key2)
+			break;
+		
+		key = key2;
+		
+		for(;;)
+		{
+			key2 = (MyListViewItem *)key->nextSibling();
+			if (!key2)
+				break;
+			key = key2;
+		}
+	}
+	
+	return key;
+}
+
+MyListViewItem *MyListViewItem::findBelow()
+{
+	MyListViewItem *key, *key2;
+	
+	key = (MyListViewItem *)firstChild();
+	if (key)
+		return key;
+		
+	key = (MyListViewItem *)nextSibling();
+	if (key)
+		return key;
+	
+	key = (MyListViewItem *)parent();
+	
+	for(;;)
+	{
+		if (!key)
+			return NULL;
+		
+		key2 = (MyListViewItem *)key->nextSibling();
+		if (key2)
+			return key2;
+		
+		key = (MyListViewItem *)key->parent();
+	}
+}
+
+
 /***************************************************************************
 
   class MyListView
@@ -354,6 +430,9 @@ static MyListView *listview_init(void *_object, void *parent)
   QObject::connect(wid, SIGNAL(pressed(QListViewItem *)), &CTreeView::manager, SLOT(clicked(QListViewItem *)));
   QObject::connect(wid, SIGNAL(itemRenamed(QListViewItem *, int)), &CTreeView::manager, SLOT(renamed(QListViewItem *, int)));
 
+  wid->setSorting(-1);
+  wid->setSelectionMode(QListView::Single);
+
   CWIDGET_new(wid, (void *)_object);
 
   THIS->dict = new QAsciiDict<MyListViewItem>;
@@ -363,9 +442,6 @@ static MyListView *listview_init(void *_object, void *parent)
   THIS->save = 0;
   THIS->rename = false;
 
-  wid->setSorting(-1);
-  wid->setSelectionMode(QListView::Single);
-
   return wid;
 }
 
@@ -380,7 +456,6 @@ BEGIN_METHOD(CTREEVIEW_new, GB_OBJECT parent)
   wid->addColumn("-");
   wid->header()->hide();
   wid->setRootIsDecorated(true);
-  wid->show();
 
 END_METHOD
 
@@ -395,7 +470,6 @@ BEGIN_METHOD(CLISTVIEW_new, GB_OBJECT parent)
   wid->setHScrollBarMode(QScrollView::AlwaysOff);
   wid->header()->hide();
   wid->setResizeMode(QListView::LastColumn);
-  wid->show();
 
 END_METHOD
 
@@ -419,8 +493,6 @@ BEGIN_METHOD(CCOLUMNVIEW_new, GB_OBJECT parent)
   
   wid->setResizeMode(QListView::LastColumn);
 
-  wid->show();
-
 END_METHOD
 
 
@@ -841,26 +913,7 @@ END_METHOD
 
 BEGIN_METHOD_VOID(CTREEVIEW_previous)
 
-	MyListViewItem *lwi, *lwn = 0;
-	
-	if (THIS->item)
-	{
-		if (THIS->item->parent())
-			lwi = (MyListViewItem *)THIS->item->parent()->firstChild(); 
-		else
-			lwi = (MyListViewItem *)WIDGET->firstChild();
-		for (;;)
-		{
-			if (!lwi || lwi == THIS->item)
-				break;
-			lwn = lwi;
-			lwi = (MyListViewItem *)lwi->nextSibling();
-		}
-	}
-
-  return_item(THIS, lwn);
-
-  //return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->prev) : 0);
+  return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->previousSibling()) : 0);
 
 END_METHOD
 
@@ -887,14 +940,14 @@ END_METHOD
 
 BEGIN_METHOD_VOID(CTREEVIEW_above)
 
-  return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->itemAbove()) : 0);
+  return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->findAbove()) : 0);
 
 END_METHOD
 
 
 BEGIN_METHOD_VOID(CTREEVIEW_below)
 
-  return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->itemBelow()) : 0);
+  return_item(THIS, THIS->item ? (MyListViewItem *)(THIS->item->findBelow()) : 0);
 
 END_METHOD
 
@@ -1236,7 +1289,7 @@ END_PROPERTY*/
 
 BEGIN_PROPERTY(CLISTVIEW_columns_count)
 
-  long col;
+  int col;
   QListView::ResizeMode mode;
   //bool *numeric;
   //int i, n;
@@ -1280,7 +1333,7 @@ END_PROPERTY
 
 BEGIN_METHOD(CLISTVIEW_columns_get, GB_INTEGER col)
 
-  long col = VARG(col);
+  int col = VARG(col);
 
   if (col < 0 || col >= WIDGET->columns())
   {
@@ -1443,9 +1496,9 @@ END_METHOD
 
 BEGIN_PROPERTY(CTREEVIEW_client_width)
 
-  //long w = WIDGET->width() - WIDGET->frameWidth() * 2;
-  //long sw = WIDGET->verticalScrollBar()->width();
-  //long width = w;
+  //int w = WIDGET->width() - WIDGET->frameWidth() * 2;
+  //int sw = WIDGET->verticalScrollBar()->width();
+  //int width = w;
 
   //if (WIDGET->verticalScrollBar()->isHidden())
   //  width -= sw;
@@ -1974,7 +2027,7 @@ void CTreeView::selected(void)
 	else
 	{
   	GB.Ref(_object);
-  	GB.Post((GB_POST_FUNC)post_select_event, (long)THIS);
+  	GB.Post((GB_POST_FUNC)post_select_event, (intptr_t)THIS);
 	}
 }
 
@@ -2007,7 +2060,7 @@ void CTreeView::renamed(QListViewItem *it, int col)
 
   THIS->item = (MyListViewItem *)it;
   GB.Ref(THIS);
-  GB.Post((void (*)())post_rename_event, (long)THIS);
+  GB.Post((void (*)())post_rename_event, (intptr_t)THIS);
 }
 
 // void CTreeView::columnClicked(QListViewItem *it, const QPoint &p, int c)
