@@ -49,15 +49,17 @@ typedef
     	unsigned expand : 1;
     	unsigned ignore : 1;
     	unsigned notified : 1;
-    	unsigned _reserved : 11;
+    	unsigned visible : 1;
+    	unsigned _reserved : 10;
     	} flag;
     GB_VARIANT_VALUE tag;
     char *tooltip;
     char *name;
     void *cursor;
+    void *font;
     CWIDGET *next;
     CWIDGET *prev;
-    long level;
+    int level;
     }
   CWIDGET;
 
@@ -68,7 +70,7 @@ typedef
   struct {
     CWIDGET widget;
     QWidget *container;
-    long arrangement;
+    int arrangement;
     }
   CCONTAINER;
 
@@ -176,8 +178,7 @@ DECLARE_PROPERTY(CCONTROL_action);
 #define EMBED_OK     1
 #define EMBED_ERROR  2
 
-void CWIDGET_new(QWidget *w, void *_object, char *klass = NULL,
-                 bool no_filter = false, bool no_tag = false);
+void CWIDGET_new(QWidget *w, void *_object, bool no_show = false, bool no_filter = false, bool no_tag = false);
 void CWIDGET_init_name(CWIDGET *_object);
 int CWIDGET_check(void *object);
 QString CWIDGET_Utf8ToQString(GB_STRING *str);
@@ -196,7 +197,7 @@ void CACTION_get(void *control);
 #ifndef __CWIDGET_CPP
 extern
 #endif
-long
+int
 //EVENT_Move,
 //EVENT_Resize,
 EVENT_MouseDown,
