@@ -385,12 +385,12 @@ static void release_grab()
 	
 	if (_mouseGrabber) 
 	{
-		qDebug("releaseMouse");
+		//qDebug("releaseMouse");
 		_mouseGrabber->releaseMouse();
 	}
 	if (_keyboardGrabber)
 	{
-		qDebug("releaseKeyboard");
+		//qDebug("releaseKeyboard");
 		_keyboardGrabber->releaseKeyboard();
 	}
 	
@@ -409,14 +409,14 @@ static void unrelease_grab()
 {
 	if (_mouseGrabber)
 	{
-		qDebug("grabMouse");
+		//qDebug("grabMouse");
 		_mouseGrabber->grabMouse();
 		_mouseGrabber = 0;
 	}
 	
 	if (_keyboardGrabber)
 	{
-		qDebug("grabKeyboard");
+		//qDebug("grabKeyboard");
 		_keyboardGrabber->grabKeyboard();
 		_keyboardGrabber = 0;
 	}
@@ -526,6 +526,8 @@ static void hook_loop()
 
   if (!must_quit())
     qApp->exec();
+  else
+  	MAIN_check_quit();
 
   //qDebug("Exit event loop");
 }
@@ -555,11 +557,11 @@ static void hook_timer(GB_TIMER *timer, bool on)
 	}
 	
 	if (on)
-		timer->id = (int)(new MyTimer(timer));
+		timer->id = (intptr_t)(new MyTimer(timer));
 }
 
 
-static void hook_watch(int fd, int type, void *callback, int param)
+static void hook_watch(int fd, int type, void *callback, intptr_t param)
 {
   CWatch::watch(fd, type, (GB_WATCH_CALLBACK)callback, param);
 }
