@@ -930,7 +930,7 @@ void GEditor::cursorHome(bool shift, bool ctrl)
 void GEditor::cursorEnd(bool shift, bool ctrl)
 {
   if (ctrl)
-    cursorGoto(numLines(), 0, shift);
+    cursorGoto(numLines() - 1, lineLength(numLines() - 1), shift);
   else
     cursorGoto(y, lineLength(y), shift);
 }
@@ -1130,7 +1130,7 @@ void GEditor::redo()
 void GEditor::selectAll()
 {
   cursorGoto(0, 0, false);
-  cursorGoto(numLines(), 0, true);
+  cursorGoto(numLines() - 1, lineLength(numLines() - 1), true);
 }
 
 void GEditor::keyPressEvent(QKeyEvent *e)
@@ -1427,19 +1427,18 @@ void GEditor::blinkTimerTimeout()
   updateLine(y);
 }
 
-void GEditor::focusInEvent(QFocusEvent *)
+void GEditor::focusInEvent(QFocusEvent *e)
 {
   startBlink();
+  QGridView::focusInEvent(e);
 }
 
-void GEditor::focusOutEvent(QFocusEvent *)
+void GEditor::focusOutEvent(QFocusEvent *e)
 {
-  //if (doc->getHighlightMode() == GDocument::Gambas)
-  //  doc->colorize(y);
   stopBlink();
+  QGridView::focusOutEvent(e);
 }
 
-
 void GEditor::scrollTimerTimeout()
 {
   int ny, nx;
@@ -1468,6 +1467,7 @@ void GEditor::setStyle(int index, GHighlightStyle *style)
 void GEditor::setNumRows(int n)
 {
 	QGridView::setNumRows(n);
+	QGridView::updateScrollBars();
 	if (contentsHeight() < visibleHeight())
     repaintContents(contentsX(), contentsHeight(), visibleWidth(), visibleHeight() - contentsHeight() + contentsX(), true);
 	//if (contentsHeight() < visibleHeight())
