@@ -24,6 +24,7 @@
 #define __GAMBAS_H
 
 #include "config.h"
+#include <stdint.h>
 
 /* Gambas API Version */
 
@@ -54,6 +55,9 @@
 #define EXPORT
 #endif
 
+#if defined(__cplusplus)
+#define __null ((intptr_t)0)
+#endif
 
 /* Gambas datatypes identifiers */
 
@@ -69,6 +73,7 @@
 #define GB_T_STRING       9
 #define GB_T_CSTRING      10
 #define GB_T_VARIANT      11
+#define GB_T_POINTER      13
 #define GB_T_NULL         15
 #define GB_T_OBJECT       16
 
@@ -76,7 +81,7 @@
 /* This type represents a Gambas datatype identifier */
 
 typedef
-  long GB_TYPE;
+  intptr_t GB_TYPE;
 
 
 /* This opaque type represents a Gambas class identifier */
@@ -93,34 +98,25 @@ typedef
 typedef
   struct {
     GB_CLASS klass;
-    long ref;
+    int ref;
     }
   GB_BASE;
 
 
-/* Gambas common value definition */
-
-typedef
-  struct {
-    GB_TYPE type;
-    long _reserved[3];
-    }
-  GB_VALUE;
-
-
 /* Gambas VARIANT datatype definition */
 
 typedef
   union {
     GB_TYPE type;
-    struct { GB_TYPE type; long value; } _boolean;
-    struct { GB_TYPE type; long value; } _byte;
-    struct { GB_TYPE type; long value; } _short;
-    struct { GB_TYPE type; long value; } _integer;
-    struct { GB_TYPE type; long long value; } _long;
+		intptr_t _reserved[3];
+    struct { GB_TYPE type; int value; } _boolean;
+    struct { GB_TYPE type; int value; } _byte;
+    struct { GB_TYPE type; int value; } _short;
+    struct { GB_TYPE type; int value; } _integer;
+    struct { GB_TYPE type; int64_t value; } _long;
     struct { GB_TYPE type; double value; } _single;
     struct { GB_TYPE type; double value; } _float;
-    struct { GB_TYPE type; long date; long time; } _date;
+    struct { GB_TYPE type; int date; int time; } _date;
     struct { GB_TYPE type; char *value; } _string;
     struct { GB_TYPE type; void *value; } _object;
     }
@@ -142,9 +138,12 @@ typedef
     GB_TYPE type;
     struct {
       char *addr;
-      long start;
-      long len;
+      int start;
+      int len;
       } value;
+    #if __WORDSIZE == 64
+		intptr_t _reserved;
+		#endif
     }
   GB_STRING;
 
@@ -154,8 +153,11 @@ typedef
 typedef
   struct {
     GB_TYPE type;
-    long value;
-    long _reserved[2];
+    int value;
+    #if __WORDSIZE == 64
+    int _pad;
+    #endif
+		intptr_t _reserved[2];
     }
   GB_INTEGER;
 
@@ -165,19 +167,36 @@ typedef
 typedef
   struct {
     GB_TYPE type;
-    long long value;
-    long _reserved;
+    int64_t value;
+    #if __WORDSIZE == 64
+    intptr_t _reserved[2];
+    #else
+    int _reserved;
+    #endif
     }
   GB_LONG;
 
+/* Gambas POINTER datatype definition */
+
+typedef
+  struct {
+    GB_TYPE type;
+    intptr_t value;
+    intptr_t _reserved[2];
+    }
+  GB_POINTER;
+
 
 /* Gambas BOOLEAN datatype definition */
 
 typedef
   struct {
     GB_TYPE type;
-    long value;
-    long _reserved[2];
+    int value;
+    #if __WORDSIZE == 64
+    int _pad;
+    #endif
+		intptr_t _reserved[2];
     }
   GB_BOOLEAN;
 
@@ -188,7 +207,11 @@ typedef
   struct {
     GB_TYPE type;
     double value;
-    long _reserved;
+    #if __WORDSIZE == 64
+    intptr_t _reserved[2];
+    #else
+    int _reserved;
+    #endif
     }
   GB_FLOAT;
 
@@ -197,8 +220,8 @@ typedef
 
 typedef
   struct {
-    long date;
-    long time;
+    int date;
+    int time;
     }
   GB_DATE_VALUE;
 
@@ -206,7 +229,11 @@ typedef
   struct {
     GB_TYPE type;
     GB_DATE_VALUE value;
-    long _reserved;
+    #if __WORDSIZE == 64
+    intptr_t _reserved[2];
+    #else
+    int _reserved;
+    #endif
     }
   GB_DATE;
 
@@ -217,26 +244,44 @@ typedef
   struct {
     GB_TYPE type;
     void *value;
-    long _reserved[2];
+    intptr_t _reserved[2];
     }
   GB_OBJECT;
 
 
+/* Gambas common value definition */
+
+typedef
+  union {
+    GB_TYPE type;
+    GB_BOOLEAN _boolean;
+    GB_INTEGER _integer;
+    GB_LONG _long;
+    GB_FLOAT _float;
+    GB_DATE _date;
+    GB_STRING _string;
+    GB_OBJECT _object;
+    GB_VARIANT _variant;
+    }
+  GB_VALUE;
+
+
 /* Predefined errors constants */
 
 #define GB_ERR_TYPE   ((char *)6)
 #define GB_ERR_ARG    ((char *)20)
+#define GB_ERR_BOUND  ((char *)21)
 
 
 /* Gambas description start macro */
 
 #define GB_DECLARE(name, size) \
-  { name, (long)GB_VERSION, (long)size }
+  { name, (intptr_t)GB_VERSION, (intptr_t)size }
 
 
 /* Gambas description end macro */
 
-#define GB_END_DECLARE  { 0 }
+#define GB_END_DECLARE  { (char *)0 }
 
 
 /* Special description identifiers */
@@ -250,9 +295,9 @@ typedef
 
 /* Description hook macros */
 
-//#define GB_HOOK_NEW(hook)    { GB_HOOK_NEW_ID, (long)hook }
-//#define GB_HOOK_FREE(hook)   { GB_HOOK_FREE_ID, (long)hook }
-#define GB_HOOK_CHECK(hook)  { GB_HOOK_CHECK_ID, (long)hook }
+//#define GB_HOOK_NEW(hook)    { GB_HOOK_NEW_ID, (int)hook }
+//#define GB_HOOK_FREE(hook)   { GB_HOOK_FREE_ID, (int)hook }
+#define GB_HOOK_CHECK(hook)  { GB_HOOK_CHECK_ID, (intptr_t)hook }
 
 
 /* Virtual class description macro */
@@ -284,37 +329,40 @@ typedef
 /* Symbol description macros */
 
 #define GB_CONSTANT(symbol, type, value) \
-  { "C" symbol, (long)type, (long)value }
+  { "C" symbol, (intptr_t)type, (intptr_t)value }
 
 #define GB_PROPERTY(symbol, type, proc) \
-  { "p" symbol, (long)type, (long)proc }
+  { "p" symbol, (intptr_t)type, (intptr_t)proc }
 
 #define GB_PROPERTY_READ(symbol, type, proc) \
-  { "r" symbol, (long)type, (long)proc }
+  { "r" symbol, (intptr_t)type, (intptr_t)proc }
 
 #define GB_PROPERTY_SELF(symbol, type) \
-  { "r" symbol, (long)type, (long)-1 }
+  { "r" symbol, (intptr_t)type, (intptr_t)(-1) }
 
 #define GB_METHOD(symbol, type, exec, signature) \
-  { "m" symbol, (long)type, (long)(exec), (long)signature }
+  { "m" symbol, (intptr_t)type, (intptr_t)exec, (intptr_t)signature }
 
 #define GB_EVENT(symbol, type, signature, id) \
-  { "::" symbol, (long)type, (long)id, (long)signature }
+  { "::" symbol, (intptr_t)type, (intptr_t)id, (intptr_t)signature }
 
 #define GB_STATIC_PROPERTY(symbol, type, proc) \
-  { "P" symbol, (long)type, (long)proc }
+  { "P" symbol, (intptr_t)type, (intptr_t)proc }
 
 #define GB_STATIC_PROPERTY_READ(symbol, type, proc) \
-  { "R" symbol, (long)type, (long)proc }
+  { "R" symbol, (intptr_t)type, (intptr_t)proc }
 
 #define GB_STATIC_PROPERTY_SELF(symbol, type) \
-  { "R" symbol, (long)type, (long)-1 }
+  { "R" symbol, (intptr_t)type, (-1) }
 
 #define GB_STATIC_METHOD(symbol, type, exec, signature) \
-  { "M" symbol, (long)type, (long)(exec), (long)signature }
+  { "M" symbol, (intptr_t)type, (intptr_t)exec, (intptr_t)signature }
 
 #define GB_INHERITS(symbol) \
-  { GB_INHERITS_ID, (long)symbol }
+  { GB_INHERITS_ID, (intptr_t)symbol }
+  
+#define GB_INTERFACE(symbol, pointer) \
+  { "C_@" symbol, (intptr_t)"p", (intptr_t)pointer } 
 
 
 /* Method implementation begin macro */
@@ -414,19 +462,24 @@ void _name(void *_object, void *_param) {
 
 /* Macro for declaring a variable used for storing an event identifier */
 
-#define DECLARE_EVENT(_event) static long _event
+#define DECLARE_EVENT(_event) static int _event
+
+
+/* Macro to help accessing enumeration index. Use only in an enumeration method implementation */
+
+#define ENUM(_type)  (*((_type *)GB.GetEnum()))
 
 
 /* Structure used for describing a class */
 
 typedef
   struct {
-    char *name;
-    long val1;
-    long val2;
-    long val3;
-    long val4;
-    long val5;
+    const char *name;
+    intptr_t val1;
+    intptr_t val2;
+    intptr_t val3;
+    intptr_t val4;
+    intptr_t val5;
     }
   GB_DESC;
 
@@ -486,13 +539,13 @@ typedef
 /* Type of a watch callback function */
 
 typedef
-  void (*GB_WATCH_CALLBACK)(int, int, long);
+  void (*GB_WATCH_CALLBACK)(int, int, intptr_t);
 
 
 /* Type of the GB.SubstString() callback */
 
 typedef
-  void (*GB_SUBST_CALLBACK)(int, char **, long *);
+  void (*GB_SUBST_CALLBACK)(int, char **, int *);
 
 
 /* Type of a posted function */
@@ -571,8 +624,8 @@ typedef
 
 typedef
 	struct {
-		long width;
-		long height;
+		int width;
+		int height;
 		int format;
 		void *data;
 		}
@@ -605,14 +658,14 @@ typedef
   struct {
     int (*open)(struct GB_STREAM *stream, const char *path, int mode, void *data);
     int (*close)(struct GB_STREAM *stream);
-    int (*read)(struct GB_STREAM *stream, char *buffer, long len);
+    int (*read)(struct GB_STREAM *stream, char *buffer, int len);
     int (*getchar)(struct GB_STREAM *stream, char *buffer);
-    int (*write)(struct GB_STREAM *stream, char *buffer, long len);
-    int (*seek)(struct GB_STREAM *stream, long long pos, int whence);
-    int (*tell)(struct GB_STREAM *stream, long long *pos);
+    int (*write)(struct GB_STREAM *stream, char *buffer, int len);
+    int (*seek)(struct GB_STREAM *stream, int64_t pos, int whence);
+    int (*tell)(struct GB_STREAM *stream, int64_t *pos);
     int (*flush)(struct GB_STREAM *stream);
     int (*eof)(struct GB_STREAM *stream);
-    int (*lof)(struct GB_STREAM *stream, long long *len);
+    int (*lof)(struct GB_STREAM *stream, int64_t *len);
     int (*handle)(struct GB_STREAM *stream);
     }
   GB_STREAM_DESC;
@@ -620,8 +673,8 @@ typedef
 typedef
   struct GB_STREAM {
     GB_STREAM_DESC *desc;
-    long _reserved;
-    long _free[6];
+    int _reserved;
+    int _free[6];
     }
   GB_STREAM;
 
@@ -657,6 +710,7 @@ typedef
     void *(*get)(void *, const char *);
     int (*exist)(void *, const char *);
     void (*list)(void *, char ***);
+    void (*release)(void *, void *);
   }
   GB_SUBCOLLECTION_DESC;
 
@@ -666,8 +720,9 @@ typedef
 typedef
   struct {
     GB_BASE object;
-    long delay;
-    long id;
+    intptr_t id;
+    intptr_t tag;
+    int delay;
     }
   GB_TIMER;
 
@@ -682,28 +737,30 @@ typedef
 
 typedef
   struct {
-    long version;
+    intptr_t version;
 
-    int (*GetInterface)(const char *, long, void *);
+    int (*GetInterface)(const char *, int, void *);
 
     void *(*Hook)(int, void *);
 
     int (*LoadComponent)(const char *);
     int (*ExistComponent)(const char *);
     char *(*CurrentComponent)(void);
+    int (*GetComponentInfo)(const char *, void **);
 
     void (*Push)(int, ...);
     int (*GetFunction)(GB_FUNCTION *, void *, const char *, const char *, const char *);
     GB_VALUE *(*Call)(GB_FUNCTION *, int, int);
+    void *(*GetClassInterface)(GB_CLASS, const char *);
 
-		int (*Loop)(long);
-    void (*Post)(void (*)(), long);
-    void (*Post2)(void (*)(), long, long);
+		int (*Loop)(int);
+    void (*Post)(void (*)(), intptr_t);
+    void (*Post2)(void (*)(), intptr_t, intptr_t);
     int (*Raise)(void *, int, int, ...);
     void (*RaiseLater)(void *, int);
     void (*CheckPost)(void);
     int (*CanRaise)(void *, int);
-    long (*GetEvent)(GB_CLASS, const char *);
+    int (*GetEvent)(GB_CLASS, const char *);
     char *(*GetLastEventName)();
     void (*RaiseTimer)(void *);
     int (*Stopped)(void);
@@ -721,6 +778,8 @@ typedef
     char *(*GetClassName)(void *);
     int (*ExistClass)(const char *);
     GB_CLASS (*FindClass)(const char *);
+    int (*ExistClassLocal)(const char *);
+    GB_CLASS (*FindClassLocal)(const char *);
     int (*Is)(void *, GB_CLASS);
     void (*Ref)(void *);
     void (*Unref)(void **);
@@ -738,8 +797,9 @@ typedef
     void (*StopAllEnum)(void *);
 
     void (*Return)(GB_TYPE, ...);
-    void (*ReturnInteger)(long);
-    void (*ReturnLong)(long long);
+    void (*ReturnInteger)(int);
+    void (*ReturnLong)(int64_t);
+    void (*ReturnPointer)(void *);
     void (*ReturnBoolean)(int);
     void (*ReturnDate)(GB_DATE *);
     void (*ReturnObject)(void *);
@@ -748,31 +808,31 @@ typedef
     void (*ReturnPtr)(GB_TYPE, void *);
 
     void (*ReturnString)(char *);
-    void (*ReturnConstString)(const char *, long);
+    void (*ReturnConstString)(const char *, int);
     void (*ReturnConstZeroString)(const char *);
-    void (*ReturnNewString)(const char *, long);
+    void (*ReturnNewString)(const char *, int);
     void (*ReturnNewZeroString)(const char *);
 
-    void (*NewString)(char **, const char *, long);
-    void (*TempString)(char **, const char *, long);
+    void (*NewString)(char **, const char *, int);
+    void (*TempString)(char **, const char *, int);
     void (*FreeString)(char **);
-    void (*ExtendString)(char **, long);
-    void (*AddString)(char **, const char *, long);
-    long (*StringLength)(char *);
+    void (*ExtendString)(char **, int);
+    void (*AddString)(char **, const char *, int);
+    int (*StringLength)(char *);
     char *(*ToZeroString)(GB_STRING *);
-    int (*MatchString)(const char *, long, const char *, long);
-    int (*NumberFromString)(int, const char *, long, GB_VALUE *);
-    int (*NumberToString)(int, double, const char *, char **, long *);
+    int (*MatchString)(const char *, int, const char *, int);
+    int (*NumberFromString)(int, const char *, int, GB_VALUE *);
+    int (*NumberToString)(int, double, const char *, char **, int *);
     char *(*Translate)(const char *);
 
-    char *(*SubstString)(const char *, long, GB_SUBST_CALLBACK);
-    void (*SubstAdd)(const char *, long);
-    int (*ConvString)(char **, const char *, long, const char *, const char *);
-    char *(*FileName)(char *, long);
-    char *(*RealFileName)(char *, long);
+    char *(*SubstString)(const char *, int, GB_SUBST_CALLBACK);
+    void (*SubstAdd)(const char *, int);
+    int (*ConvString)(char **, const char *, int, const char *, const char *);
+    char *(*FileName)(char *, int);
+    char *(*RealFileName)(char *, int);
 
-    int (*LoadFile)(const char *, long, char **, long *);
-    void (*ReleaseFile)(char **, long);
+    int (*LoadFile)(const char *, int, char **, int *);
+    void (*ReleaseFile)(char **, int);
     int (*ExistFile)(char *);
     char *(*GetTempDir)(void);
 
@@ -783,32 +843,32 @@ typedef
 
     GB_DATE_SERIAL *(*SplitDate)(GB_DATE *);
     int (*MakeDate)(GB_DATE_SERIAL *, GB_DATE *);
-    void (*MakeDateFromTime)(long, long, GB_DATE *);
+    void (*MakeDateFromTime)(int, int, GB_DATE *);
     int (*GetTime)(double *, int);
 
-    void (*Watch)(int, int, void *, long);
+    void (*Watch)(int, int, void *, int);
 
     GB_VALUE *(*Eval)(void *, void *);
 
-    void (*Alloc)(void **, long);
+    void (*Alloc)(void **, int);
     void (*Free)(void **);
-    void (*Realloc)(void **, long);
+    void (*Realloc)(void **, int);
 
-    void (*NewArray)(void *, long, long);
+    void (*NewArray)(void *, int, int);
     void (*FreeArray)(void *);
-    long (*Count)(void *);
+    int (*Count)(void *);
     void *(*Add)(void *);
-    void *(*Insert)(void *, long, long);
-    void (*Remove)(void *, long, long);
+    void *(*Insert)(void *, int, int);
+    void (*Remove)(void *, int, int);
 
     void (*PrintData)(GB_TYPE, void *);
-    void (*PrintString)(char *, long);
+    void (*PrintString)(char *, int);
 
     struct {
       void (*New)(GB_SUBCOLLECTION *, GB_SUBCOLLECTION_DESC *, void *);
-      void (*Add)(void *, const char *, long, void *);
-      void (*Remove)(void *, const char *, long);
-      void *(*Get)(void *, const char *, long);
+      void (*Add)(void *, const char *, int, void *);
+      void (*Remove)(void *, const char *, int);
+      void *(*Get)(void *, const char *, int);
       void *(*Container)(void *);
       }
     SubCollection;
@@ -816,7 +876,7 @@ typedef
     int (*ToLower)(int);
     int (*ToUpper)(int);
     int (*StrCaseCmp)(const char *, const char *);
-    int (*StrNCaseCmp)(const char *, const char *, long);
+    int (*StrNCaseCmp)(const char *, const char *, int);
 
     struct {
       char *(*Name)(void);
@@ -830,32 +890,33 @@ typedef
     struct {
       char *(*Charset)(void);
       char *(*Language)(void);
+      char *(*DomainName)(void);
       }
     System;
 
     struct {
-      void (*New)(GB_ARRAY *, GB_TYPE, long);
-      long (*Count)(GB_ARRAY);
+      void (*New)(GB_ARRAY *, GB_TYPE, int);
+      int (*Count)(GB_ARRAY);
       void *(*Add)(GB_ARRAY);
-      void *(*Get)(GB_ARRAY, long);
+      void *(*Get)(GB_ARRAY, int);
       }
     Array;
 
     struct {
       void (*New)(GB_COLLECTION *, int);
-      long (*Count)(GB_COLLECTION);
-      void (*Set)(GB_COLLECTION, const char *, long, GB_VARIANT *);
-      int (*Get)(GB_COLLECTION, const char *, long, GB_VARIANT *);
+      int (*Count)(GB_COLLECTION);
+      void (*Set)(GB_COLLECTION, const char *, int, GB_VARIANT *);
+      int (*Get)(GB_COLLECTION, const char *, int, GB_VARIANT *);
       }
     Collection;
 
     struct {
       void (*New)(GB_HASHTABLE *, int);
       void (*Free)(GB_HASHTABLE *);
-      long (*Count)(GB_HASHTABLE);
-      void (*Add)(GB_HASHTABLE, const char *, long, void *);
-      void (*Remove)(GB_HASHTABLE, const char *, long);
-      int (*Get)(GB_HASHTABLE, const char *, long, void **);
+      int (*Count)(GB_HASHTABLE);
+      void (*Add)(GB_HASHTABLE, const char *, int, void *);
+      void (*Remove)(GB_HASHTABLE, const char *, int);
+      int (*Get)(GB_HASHTABLE, const char *, int, void **);
       void (*Enum)(GB_HASHTABLE, GB_HASHTABLE_ENUM_FUNC);
       }
     HashTable;
