@@ -30,8 +30,7 @@
 #include "gb_table.h"
 #include "gb_file.h"
 #include "gb_arch.h"
-
-#include "gbx_list.h"
+#include "gb_list.h"
 
 typedef
   struct {
@@ -48,8 +47,8 @@ typedef
   struct {
     ARCHIVE *arch;
     ARCH_SYMBOL *sym;
-    long pos;
-    long len;
+    int pos;
+    int len;
     }
   ARCHIVE_FIND;
 
@@ -69,14 +68,14 @@ PUBLIC void ARCHIVE_load(ARCHIVE *arch);
 
 PUBLIC bool ARCHIVE_get(ARCHIVE *arch, const char *path, int len_path, ARCHIVE_FIND *find);
 
-PUBLIC bool ARCHIVE_read(ARCHIVE *arch, long pos, void *buffer, long len);
+PUBLIC bool ARCHIVE_read(ARCHIVE *arch, int pos, void *buffer, int len);
 
 PUBLIC bool ARCHIVE_exist(ARCHIVE *arch, const char *path);
 PUBLIC void ARCHIVE_stat(ARCHIVE *arch, const char *path, FILE_STAT *info);
 PUBLIC bool ARCHIVE_is_dir(ARCHIVE *arch, const char *path);
 
 PUBLIC void ARCHIVE_dir_first(ARCHIVE *arch, const char *path, const char *pattern);
-PUBLIC bool ARCHIVE_dir_next(char **name, long *len, int attr);
+PUBLIC bool ARCHIVE_dir_next(char **name, int *len, int attr);
 
 PUBLIC bool ARCHIVE_get_current(ARCHIVE **parch);
 
