@@ -46,7 +46,6 @@
 #include "gbx_c_array.h"
 
 
-
 static bool check_not_multi(CARRAY *_object)
 {
   if (THIS->dim)
@@ -58,6 +57,7 @@ static bool check_not_multi(CARRAY *_object)
     return FALSE;
 }
 
+
 static int get_dim(CARRAY *_object)
 {
   int d;
@@ -74,6 +74,7 @@ static int get_dim(CARRAY *_object)
   }
 }
 
+
 static int get_bound(CARRAY *_object, int d)
 {
   if (!THIS->dim)
@@ -153,6 +154,12 @@ static void *get_data_multi(CARRAY *_object, GB_INTEGER *arg, int nparam)
   }
   else
   {
+    if (nparam != 1)
+    {
+      GB_Error((char *)E_NDIM);
+      return NULL;
+    }
+    
     index = arg->value;
 
     if ((index < 0) || (index >= ARRAY_count(THIS->data)))
@@ -262,16 +269,12 @@ static void *insert(CARRAY *_object, int index)
 }
 
 
-
-
-
-PUBLIC void CARRAY_get_value(CARRAY *_object, int index, VALUE *value)
+void CARRAY_get_value(CARRAY *_object, int index, VALUE *value)
 {
 	VALUE_read(value, get_data(THIS, index), THIS->type);
 }
 
 
-
 BEGIN_METHOD(CARRAY_new, GB_INTEGER size)
 
   TYPE type;
@@ -306,6 +309,8 @@ BEGIN_METHOD(CARRAY_new, GB_INTEGER size)
     type = T_VARIANT;
 	else if (klass == CLASS_ObjectArray)
 		type = T_OBJECT;
+	else if (klass == CLASS_PointerArray)
+		type = T_POINTER;
 	else
 	{
 		GB_Error("Bad array type");
@@ -369,6 +374,7 @@ BEGIN_PROPERTY(CARRAY_type)
 
 END_PROPERTY
 
+
 BEGIN_METHOD_VOID(CARRAY_free)
 
   release(THIS, 0, -1);
@@ -389,7 +395,7 @@ END_METHOD
 
 BEGIN_PROPERTY(CARRAY_data)
 
-  GB_ReturnInt((int)THIS->data);
+  GB_ReturnPointer(THIS->data);
 
 END_PROPERTY
 
@@ -620,15 +626,20 @@ BEGIN_METHOD(CARRAY_insert, GB_OBJECT array; GB_INTEGER pos)
 
   int pos = VARGOPT(pos, -1);
   CARRAY *array = (CARRAY *)VARG(array);
-  int count = ARRAY_count(array->data);
+  int count;
   void *data;
 
+	if (GB_CheckObject(array))
+		return;
+
   if (check_not_multi(THIS))
   {
   	GB_ReturnNull();
     return;
 	}
 
+  count = ARRAY_count(array->data);
+  
   if (count > 0)
   {
     if (pos < 0)
@@ -966,7 +977,7 @@ END_METHOD
 #endif /* #ifndef GBX_INFO */
 
 
-PUBLIC GB_DESC NATIVE_ArrayBounds[] =
+GB_DESC NATIVE_ArrayBounds[] =
 {
   GB_DECLARE(".Array.Bounds", sizeof(CARRAY)), GB_NOT_CREATABLE(),
 
@@ -976,7 +987,7 @@ PUBLIC GB_DESC NATIVE_ArrayBounds[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Array[] =
+GB_DESC NATIVE_Array[] =
 {
   GB_DECLARE("Array", sizeof(CARRAY)), GB_NOT_CREATABLE(),
 
@@ -987,7 +998,7 @@ PUBLIC GB_DESC NATIVE_Array[] =
   GB_PROPERTY_READ("Max", "i", CARRAY_max),
   GB_PROPERTY_READ("Length", "i", CARRAY_count),
   GB_PROPERTY_READ("Dim", "i", CARRAY_dim),
-  GB_PROPERTY_READ("Data", "i", CARRAY_data),
+  GB_PROPERTY_READ("Data", "p", CARRAY_data),
   GB_PROPERTY_SELF("Bounds", ".Array.Bounds"),
 
   GB_METHOD("Remove", NULL, CARRAY_remove, "(Index)i[(Length)i]"),
@@ -1004,7 +1015,7 @@ PUBLIC GB_DESC NATIVE_Array[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_BooleanArray[] =
+GB_DESC NATIVE_BooleanArray[] =
 {
   GB_DECLARE("Boolean[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1034,21 +1045,21 @@ PUBLIC GB_DESC NATIVE_BooleanArray[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_ByteArray[] =
+GB_DESC NATIVE_ByteArray[] =
 {
   GB_DECLARE("Byte[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
   GB_METHOD("_new", NULL, CARRAY_new, "[(Size)i.]"),
 
-  GB_METHOD("Add", NULL, CARRAY_integer_add, "(Value)i[(Index)i]"),
-  GB_METHOD("Push", NULL, CARRAY_integer_push, "(Value)i"),
-  GB_METHOD("_put", NULL, CARRAY_byte_put, "(Value)i(Index)i."),
-  GB_METHOD("Find", "i", CARRAY_integer_find, "(Value)i"),
-  GB_METHOD("Exist", "b", CARRAY_integer_exist, "(Value)i"),
+  GB_METHOD("Add", NULL, CARRAY_integer_add, "(Value)c[(Index)i]"),
+  GB_METHOD("Push", NULL, CARRAY_integer_push, "(Value)c"),
+  GB_METHOD("_put", NULL, CARRAY_byte_put, "(Value)c(Index)i."),
+  GB_METHOD("Find", "i", CARRAY_integer_find, "(Value)c"),
+  GB_METHOD("Exist", "b", CARRAY_integer_exist, "(Value)c"),
 
-  GB_METHOD("Pop", "i", CARRAY_pop, NULL),
-  GB_METHOD("_get", "i", CARRAY_get, "(Index)i."),
-  GB_METHOD("_next", "i", CARRAY_next, NULL),
+  GB_METHOD("Pop", "c", CARRAY_pop, NULL),
+  GB_METHOD("_get", "c", CARRAY_get, "(Index)i."),
+  GB_METHOD("_next", "c", CARRAY_next, NULL),
 
   GB_METHOD("Read", NULL, CARRAY_read, "(Stream)Stream;[(Start)i(Length)i]"),
   GB_METHOD("Write", NULL, CARRAY_write, "(Stream)Stream;[(Start)i(Length)i]"),
@@ -1058,27 +1069,27 @@ PUBLIC GB_DESC NATIVE_ByteArray[] =
   GB_METHOD("Extract", "Byte[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Delete", "Byte[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Sort", "Byte[]", CARRAY_sort, "[(Mode)i]"),
-  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)i[(Start)i(Length)i]"),
+  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)c[(Start)i(Length)i]"),
 
   GB_END_DECLARE
 };
 
 
-PUBLIC GB_DESC NATIVE_ShortArray[] =
+GB_DESC NATIVE_ShortArray[] =
 {
   GB_DECLARE("Short[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
   GB_METHOD("_new", NULL, CARRAY_new, "[(Size)i.]"),
 
-  GB_METHOD("Add", NULL, CARRAY_integer_add, "(Value)i[(Index)i]"),
-  GB_METHOD("Push", NULL, CARRAY_integer_push, "(Value)i"),
-  GB_METHOD("_put", NULL, CARRAY_short_put, "(Value)i(Index)i."),
-  GB_METHOD("Find", "i", CARRAY_integer_find, "(Value)i"),
-  GB_METHOD("Exist", "b", CARRAY_integer_exist, "(Value)i"),
+  GB_METHOD("Add", NULL, CARRAY_integer_add, "(Value)h[(Index)i]"),
+  GB_METHOD("Push", NULL, CARRAY_integer_push, "(Value)h"),
+  GB_METHOD("_put", NULL, CARRAY_short_put, "(Value)h(Index)i."),
+  GB_METHOD("Find", "i", CARRAY_integer_find, "(Value)h"),
+  GB_METHOD("Exist", "b", CARRAY_integer_exist, "(Value)h"),
 
-  GB_METHOD("Pop", "i", CARRAY_pop, NULL),
-  GB_METHOD("_get", "i", CARRAY_get, "(Index)i."),
-  GB_METHOD("_next", "i", CARRAY_next, NULL),
+  GB_METHOD("Pop", "h", CARRAY_pop, NULL),
+  GB_METHOD("_get", "h", CARRAY_get, "(Index)i."),
+  GB_METHOD("_next", "h", CARRAY_next, NULL),
 
   GB_METHOD("Read", NULL, CARRAY_read, "(Stream)Stream;[(Start)i(Length)i]"),
   GB_METHOD("Write", NULL, CARRAY_write, "(Stream)Stream;[(Start)i(Length)i]"),
@@ -1088,13 +1099,13 @@ PUBLIC GB_DESC NATIVE_ShortArray[] =
   GB_METHOD("Extract", "Short[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Delete", "Short[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Sort", "Short[]", CARRAY_sort, "[(Mode)i]"),
-  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)i[(Start)i(Length)i]"),
+  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)h[(Start)i(Length)i]"),
 
   GB_END_DECLARE
 };
 
 
-PUBLIC GB_DESC NATIVE_IntegerArray[] =
+GB_DESC NATIVE_IntegerArray[] =
 {
   GB_DECLARE("Integer[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1124,7 +1135,7 @@ PUBLIC GB_DESC NATIVE_IntegerArray[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_LongArray[] =
+GB_DESC NATIVE_LongArray[] =
 {
   GB_DECLARE("Long[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1154,8 +1165,52 @@ PUBLIC GB_DESC NATIVE_LongArray[] =
   GB_END_DECLARE
 };
 
+#ifdef OS_64BITS
+#define CARRAY_pointer_add CARRAY_long_add
+#define CARRAY_pointer_push CARRAY_long_push
+#define CARRAY_pointer_put CARRAY_long_put
+#define CARRAY_pointer_find CARRAY_long_find
+#define CARRAY_pointer_exist CARRAY_long_exist
+#else
+#define CARRAY_pointer_add CARRAY_integer_add
+#define CARRAY_pointer_push CARRAY_integer_push
+#define CARRAY_pointer_put CARRAY_integer_put
+#define CARRAY_pointer_find CARRAY_integer_find
+#define CARRAY_pointer_exist CARRAY_integer_exist
+#endif
 
-PUBLIC GB_DESC NATIVE_StringArray[] =
+GB_DESC NATIVE_PointerArray[] =
+{
+  GB_DECLARE("Pointer[]", sizeof(CARRAY)), GB_INHERITS("Array"),
+
+  GB_METHOD("_new", NULL, CARRAY_new, "[(Size)i.]"),
+
+  GB_METHOD("Add", NULL, CARRAY_long_add, "(Value)p[(Index)i]"),
+  GB_METHOD("Push", NULL, CARRAY_long_push, "(Value)p"),
+  GB_METHOD("_put", NULL, CARRAY_long_put, "(Value)p(Index)i."),
+  GB_METHOD("Find", "i", CARRAY_long_find, "(Value)p"),
+  GB_METHOD("Exist", "b", CARRAY_long_exist, "(Value)p"),
+
+  GB_METHOD("Pop", "p", CARRAY_pop, NULL),
+  GB_METHOD("_get", "p", CARRAY_get, "(Index)i."),
+  GB_METHOD("_next", "p", CARRAY_next, NULL),
+
+  GB_METHOD("Read", NULL, CARRAY_read, "(Stream)Stream;[(Start)i(Length)i]"),
+  GB_METHOD("Write", NULL, CARRAY_write, "(Stream)Stream;[(Start)i(Length)i]"),
+
+  GB_METHOD("Insert", "Pointer[]", CARRAY_insert, "(Array)Pointer[];[(Pos)i]"),
+
+  GB_METHOD("Copy", "Pointer[]", CARRAY_copy, "[(Start)i(Length)i]"),
+  GB_METHOD("Extract", "Pointer[]", CARRAY_extract, "(Start)i[(Length)i]"),
+  GB_METHOD("Delete", "Pointer[]", CARRAY_extract, "(Start)i[(Length)i]"),
+  GB_METHOD("Sort", "Pointer[]", CARRAY_sort, "[(Mode)i]"),
+  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)p[(Start)i(Length)i]"),
+
+  GB_END_DECLARE
+};
+
+
+GB_DESC NATIVE_StringArray[] =
 {
   GB_DECLARE("String[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1185,7 +1240,7 @@ PUBLIC GB_DESC NATIVE_StringArray[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_FloatArray[] =
+GB_DESC NATIVE_FloatArray[] =
 {
   GB_DECLARE("Float[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1216,21 +1271,21 @@ PUBLIC GB_DESC NATIVE_FloatArray[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_SingleArray[] =
+GB_DESC NATIVE_SingleArray[] =
 {
   GB_DECLARE("Single[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
   GB_METHOD("_new", NULL, CARRAY_new, "[(Size)i.]"),
 
-  GB_METHOD("Add", NULL, CARRAY_float_add, "(Value)f[(Index)i]"),
-  GB_METHOD("Push", NULL, CARRAY_float_push, "(Value)f"),
-  GB_METHOD("_put", NULL, CARRAY_single_put, "(Value)f(Index)i."),
-  GB_METHOD("Find", "i", CARRAY_float_find, "(Value)f"),
-  GB_METHOD("Exist", "b", CARRAY_float_exist, "(Value)f"),
+  GB_METHOD("Add", NULL, CARRAY_float_add, "(Value)g[(Index)i]"),
+  GB_METHOD("Push", NULL, CARRAY_float_push, "(Value)g"),
+  GB_METHOD("_put", NULL, CARRAY_single_put, "(Value)g(Index)i."),
+  GB_METHOD("Find", "i", CARRAY_float_find, "(Value)g"),
+  GB_METHOD("Exist", "b", CARRAY_float_exist, "(Value)g"),
 
-  GB_METHOD("Pop", "f", CARRAY_pop, NULL),
-  GB_METHOD("_get", "f", CARRAY_get, "(Index)i."),
-  GB_METHOD("_next", "f", CARRAY_next, NULL),
+  GB_METHOD("Pop", "g", CARRAY_pop, NULL),
+  GB_METHOD("_get", "g", CARRAY_get, "(Index)i."),
+  GB_METHOD("_next", "g", CARRAY_next, NULL),
 
   GB_METHOD("Read", NULL, CARRAY_read, "(Stream)Stream;[(Start)i(Length)i]"),
   GB_METHOD("Write", NULL, CARRAY_write, "(Stream)Stream;[(Start)i(Length)i]"),
@@ -1241,13 +1296,13 @@ PUBLIC GB_DESC NATIVE_SingleArray[] =
   GB_METHOD("Extract", "Single[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Delete", "Single[]", CARRAY_extract, "(Start)i[(Length)i]"),
   GB_METHOD("Sort", "Single[]", CARRAY_sort, "[(Mode)i]"),
-  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)f[(Start)i(Length)i]"),
+  GB_METHOD("Fill", NULL, CARRAY_fill, "(Value)g[(Start)i(Length)i]"),
 
   GB_END_DECLARE
 };
 
 
-PUBLIC GB_DESC NATIVE_DateArray[] =
+GB_DESC NATIVE_DateArray[] =
 {
   GB_DECLARE("Date[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1278,7 +1333,7 @@ PUBLIC GB_DESC NATIVE_DateArray[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_ObjectArray[] =
+GB_DESC NATIVE_ObjectArray[] =
 {
   GB_DECLARE("Object[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1307,7 +1362,7 @@ PUBLIC GB_DESC NATIVE_ObjectArray[] =
 
 #if 0
 #ifndef GBX_INFO
-PUBLIC GB_DESC NATIVE_TemplateArray[ARRAY_TEMPLATE_NDESC] =
+GB_DESC NATIVE_TemplateArray[ARRAY_TEMPLATE_NDESC] =
 {
   GB_DECLARE("*[]", sizeof(CARRAY)), GB_INHERITS("Object[]"),
 
@@ -1335,7 +1390,7 @@ PUBLIC GB_DESC NATIVE_TemplateArray[ARRAY_TEMPLATE_NDESC] =
 #endif
 #endif
 
-PUBLIC GB_DESC NATIVE_VariantArray[] =
+GB_DESC NATIVE_VariantArray[] =
 {
   GB_DECLARE("Variant[]", sizeof(CARRAY)), GB_INHERITS("Array"),
 
@@ -1408,7 +1463,7 @@ static void add_entry()
 }
 
 
-PUBLIC void CARRAY_split(CARRAY *_object, const char *str, int lstr, const char *sep, const char *esc, bool no_void)
+void CARRAY_split(CARRAY *_object, const char *str, int lstr, const char *sep, const char *esc, bool no_void)
 {
 	int i;
 	char c;
@@ -1477,7 +1532,7 @@ PUBLIC void CARRAY_split(CARRAY *_object, const char *str, int lstr, const char
 
 /* Gambas API */
 
-PUBLIC void GB_ArrayNew(GB_ARRAY *array, uint type, int size)
+void GB_ArrayNew(GB_ARRAY *array, uint type, int size)
 {
   CLASS *class;
   int np;
@@ -1504,23 +1559,24 @@ PUBLIC void GB_ArrayNew(GB_ARRAY *array, uint type, int size)
     case GB_T_STRING: class = CLASS_StringArray; break;
     case GB_T_DATE: class = CLASS_DateArray; break;
     case GB_T_OBJECT: class = CLASS_ObjectArray; break;
+    case GB_T_POINTER: class = CLASS_PointerArray; break;
     default: class = CLASS_VariantArray; break;
   }
 
   OBJECT_create((void **)array, class, NULL, NULL, np);
 }
 
-PUBLIC int GB_ArrayCount(GB_ARRAY array)
+int GB_ArrayCount(GB_ARRAY array)
 {
   return ARRAY_count(((CARRAY *)array)->data);
 }
 
-PUBLIC void *GB_ArrayAdd(GB_ARRAY array)
+void *GB_ArrayAdd(GB_ARRAY array)
 {
   return insert((CARRAY *)array, -1);
 }
 
-PUBLIC void *GB_ArrayGet(GB_ARRAY array, int index)
+void *GB_ArrayGet(GB_ARRAY array, int index)
 {
   return get_data((CARRAY *)array, index);
 }
