@@ -37,16 +37,17 @@
 #include "gbx_class.h"
 #include "gbx_class_desc.h"
 #include "gbx_exec.h"
-
+#include "gbx_event.h"
 #include "gbx_object.h"
 #include "gbx_c_array.h"
+#include "gbx_c_gambas.h"
 #include "gbx_c_class.h"
 
 static CLASS_DESC_SYMBOL *_current_symbol = NULL;
 
 static CLASS_DESC *get_desc(CLASS *class, const char *name)
 {
-  long index;
+  int index;
 
   index = CLASS_find_symbol(class, name);
 
@@ -187,7 +188,7 @@ END_PROPERTY
 BEGIN_METHOD_VOID(class_next)
 
   TABLE *table = CLASS_get_table();
-  long *index = (long *)GB_GetEnum();
+  int *index = (int *)GB_GetEnum();
   CLASS *class;
 
   for(;;)
@@ -534,7 +535,7 @@ BEGIN_METHOD(object_get_property, GB_OBJECT object; GB_STRING property)
     EXEC.drop = FALSE;
     EXEC.nparam = 0;
     EXEC.native = FALSE;
-    EXEC.index = (long)desc->property.read;
+    EXEC.index = (int)(intptr_t)desc->property.read;
     //EXEC.func = &class->load->func[(long)desc->property.read];
 
     EXEC_function_keep();
@@ -625,7 +626,7 @@ BEGIN_METHOD(object_set_property, GB_OBJECT object; GB_STRING property; GB_VARIA
     EXEC.drop = FALSE;
     EXEC.nparam = 1;
     EXEC.native = FALSE;
-    EXEC.index = (long)desc->property.write;
+    EXEC.index = (int)(intptr_t)desc->property.write;
     //EXEC.func = &class->load->func[(long)desc->property.write];
 
     EXEC_function();
@@ -653,7 +654,10 @@ BEGIN_METHOD(object_attach, GB_OBJECT object; GB_OBJECT parent; GB_STRING name)
   if (GB_CheckObject(parent))
     return;
 
-  OBJECT_attach(object, parent, GB_ToZeroString(ARG(name)));
+ 	OBJECT_attach(object, parent, GB_ToZeroString(ARG(name)));
+	
+	if (OBJECT_is(object, CLASS_Observer))
+		COBSERVER_attach((COBSERVER *)object, parent, GB_ToZeroString(ARG(name)));
 
 END_METHOD
 
@@ -666,7 +670,10 @@ BEGIN_METHOD(object_detach, GB_OBJECT object)
   if (GB_CheckObject(object))
     return;
 
-  OBJECT_detach(object);
+	if (OBJECT_is(object, CLASS_Observer))
+		COBSERVER_detach((COBSERVER *)object);
+ 	
+ 	OBJECT_detach(object);
 
 END_METHOD
 
@@ -856,10 +863,16 @@ BEGIN_METHOD(object_new, GB_STRING class; GB_OBJECT params)
 END_METHOD
 
 
+BEGIN_PROPERTY(object_event_name)
+
+	GB_ReturnString(EVENT_Name);
+
+END_PROPERTY
+
 #endif
 
 
-PUBLIC GB_DESC NATIVE_Symbol[] =
+GB_DESC NATIVE_Symbol[] =
 {
   GB_DECLARE(".Symbol", 0), GB_VIRTUAL_CLASS(),
 
@@ -876,7 +889,7 @@ PUBLIC GB_DESC NATIVE_Symbol[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_ClassSymbols[] =
+GB_DESC NATIVE_ClassSymbols[] =
 {
   GB_DECLARE(".ClassSymbols", 0), GB_VIRTUAL_CLASS(),
 
@@ -887,7 +900,7 @@ PUBLIC GB_DESC NATIVE_ClassSymbols[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Components[] =
+GB_DESC NATIVE_Components[] =
 {
   GB_DECLARE("Components", 0),  GB_VIRTUAL_CLASS(),
 
@@ -900,7 +913,7 @@ PUBLIC GB_DESC NATIVE_Components[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Component[] =
+GB_DESC NATIVE_Component[] =
 {
   GB_DECLARE("Component", 0),  GB_VIRTUAL_CLASS(),
 
@@ -915,7 +928,7 @@ PUBLIC GB_DESC NATIVE_Component[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Classes[] =
+GB_DESC NATIVE_Classes[] =
 {
   GB_DECLARE("Classes", 0),  GB_VIRTUAL_CLASS(),
 
@@ -927,7 +940,7 @@ PUBLIC GB_DESC NATIVE_Classes[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Class[] =
+GB_DESC NATIVE_Class[] =
 {
   GB_DECLARE("Class", 0),  GB_VIRTUAL_CLASS(),
 
@@ -956,7 +969,7 @@ PUBLIC GB_DESC NATIVE_Class[] =
 };
 
 
-PUBLIC GB_DESC NATIVE_Object[] =
+GB_DESC NATIVE_Object[] =
 {
   GB_DECLARE("Object", 0),  GB_VIRTUAL_CLASS(),
 
@@ -975,6 +988,7 @@ PUBLIC GB_DESC NATIVE_Object[] =
   GB_STATIC_METHOD("Unlock", NULL, object_unlock, "(Object)o"),
   GB_STATIC_METHOD("IsLocked", "b", object_is_locked, "(Object)o"),
   GB_STATIC_METHOD("Count", "i", object_count, "(Object)o"),
+  GB_STATIC_PROPERTY_READ("_LastEventName", "s", object_event_name),
 
   GB_END_DECLARE
 };
