@@ -26,6 +26,11 @@
 
 #include "config.h"
 #include "gb_common.h"
+
+#if HAVE_FFI_COMPONENT
+#include <ffi.h>
+#endif
+
 #include "gb_common_buffer.h"
 #include "gb_table.h"
 #include "gbx_type.h"
@@ -36,14 +41,6 @@
 
 #include "gbx_extern.h"
 
-/* Daniel Campos trick :-) */
-
-typedef
-  struct {
-    int args[32];
-  }
-  ARGS;
-
 typedef
   struct {
     SYMBOL sym;
@@ -53,6 +50,15 @@ typedef
 
 static TABLE *_table = NULL;
 
+#if HAVE_FFI_COMPONENT
+static ffi_type *_to_ffi_type[17] = {
+	&ffi_type_void, &ffi_type_sint32, &ffi_type_sint32, &ffi_type_sint32, 
+	&ffi_type_sint32, &ffi_type_sint64, &ffi_type_float, &ffi_type_double, 
+	&ffi_type_void,	&ffi_type_pointer, &ffi_type_pointer, &ffi_type_void, 
+	&ffi_type_void, &ffi_type_void, &ffi_type_void, &ffi_type_pointer,
+	&ffi_type_pointer
+	};
+#endif
 
 static lt_dlhandle get_library(char *name)
 {
@@ -71,12 +77,14 @@ static lt_dlhandle get_library(char *name)
     if (!p)
       sprintf(COMMON_buffer, "%s." SHARED_LIBRARY_EXT, name);
     else
-      sprintf(COMMON_buffer, "%.*s." SHARED_LIBRARY_EXT ".%s", p - name, name, p + 1);
+      sprintf(COMMON_buffer, "%.*s." SHARED_LIBRARY_EXT ".%s", (int)(p - name), name, p + 1);
       
     name = COMMON_buffer;
     
     #ifndef DONT_USE_LTDL
+      /* no more available in libltld ?
       lt_dlopen_flag = RTLD_LAZY;
+      */
       esym->handle = lt_dlopenext(name);
     #else
       esym->handle = dlopen(name, RTLD_LAZY);
@@ -91,7 +99,7 @@ static lt_dlhandle get_library(char *name)
   return esym->handle;
 }  
   
-
+#if 0
 static int put_arg(void *addr, VALUE *value)
 {
   static void *jump[16] = {
@@ -126,7 +134,7 @@ __INTEGER:
 
 __LONG:
 
-  *((long long *)addr) = value->_long.value;
+  *((int64_t *)addr) = value->_long.value;
   return 2;
 
 __SINGLE:
@@ -178,7 +186,7 @@ __FUNCTION:
 
   ERROR_panic("Bad type (%d) for EXTERN_call", value->type);
 }
-
+#endif
 
 
 
@@ -205,7 +213,8 @@ static void *get_function(CLASS_EXTERN *ext)
   
   return func;
 }
-  
+
+
 /*
   EXEC.class : the class
   EXEC.index : the extern function index
@@ -213,73 +222,148 @@ static void *get_function(CLASS_EXTERN *ext)
   EXEC.drop : if the return value should be dropped.
 */
 
-#define CAST(_type, _func) (*((_type (*)())_func))
-
-PUBLIC void EXTERN_call(void)
+#if HAVE_FFI_COMPONENT
+void EXTERN_call(void)
 {
+  static const void *jump[17] = {
+    &&__VOID, &&__BOOLEAN, &&__BYTE, &&__SHORT, &&__INTEGER, &&__LONG, &&__SINGLE, &&__FLOAT, &&__DATE,
+    &&__STRING, &&__STRING, &&__VARIANT, &&__ARRAY, &&__FUNCTION, &&__CLASS, &&__NULL, &&__OBJECT
+    };
+  static const int use_temp[17] = { 0, 0, 0, 0, 0, 0, sizeof(float), 0, 0, sizeof(char *), sizeof(char *), 0, 0, 0, 0, 0, sizeof(void *) };
+  static char temp[4 * sizeof(void *)];
+  static void *null = 0;
+    
   CLASS_EXTERN *ext = &EXEC.class->load->ext[EXEC.index];
   int nparam = EXEC.nparam;
-  int i, sz;
-  VALUE *value;
+  ffi_cif cif;
+  ffi_type *types[nparam];
+  ffi_type *rtype;
+  void *args[nparam];
+  int rvalue[4];
   TYPE *sign;
-  ARGS args;
-  int *parg, *marg;
+  VALUE *value;
+  char *tmp = NULL;
+  char *next_tmp;
   void *func;
-  
+  int i, t;
+
   if (nparam < ext->n_param)
     THROW(E_NEPARAM);
   if (nparam > ext->n_param)
     THROW(E_TMPARAM);
   
-  if (nparam)
-  {
-    value = &SP[-nparam];
-    sign = (TYPE *)ext->param;
-    parg = (int *)&args;
-    marg = parg + sizeof(ARGS) / sizeof(int);
+  sign = (TYPE *)ext->param;
+  value = &SP[-nparam];
+  next_tmp = temp;
   
-    for (i = 0, sz = 0; i < nparam; i++, value++, sign++)
-    {
-      VALUE_conv(value, *sign);
-      if (parg >= marg)
-        THROW(E_TMPARAM);      
-      parg += put_arg(parg, value);
-    }
+  for (i = 0; i < nparam; i++, value++, sign++)
+  {
+  	VALUE_conv(value, *sign);
+  	
+		if (TYPE_is_object(value->type))
+			t = T_OBJECT;
+		else
+			t = (int)value->type;
+			
+		if (use_temp[t])
+		{
+			tmp = next_tmp;
+			if ((tmp + use_temp[t]) > &temp[sizeof(temp)])
+				THROW(E_TMPARAM);
+			args[i] = tmp;
+			next_tmp = tmp + use_temp[t];
+		}
+  	types[i] = _to_ffi_type[t];
+		goto *jump[t];
+
+	__BOOLEAN:
+	__BYTE:
+	__SHORT:
+	__INTEGER:
+		args[i] = &value->_integer.value;
+		continue;
+	
+	__LONG:
+		args[i] = &value->_long.value;
+		continue;
+	
+	__SINGLE:
+		*((float *)tmp) = (float)value->_float.value;
+		continue;
+	
+	__FLOAT:
+		args[i] = &value->_float.value;
+		continue;
+	
+	__STRING:
+		*((char **)tmp) = (char *)(value->_string.addr + value->_string.start);
+		continue;
+	
+	__OBJECT:	
+		{
+			void *ob = value->_object.object;
+			CLASS *class = OBJECT_class(ob);
+			
+			if (!CLASS_is_native(class) && class == CLASS_Class)
+				*((void **)tmp) = class->stat;
+			else
+				*((void **)tmp) = (char *)ob + sizeof(OBJECT);
+		}
+		continue;
+	
+	__NULL:
+		args[i] = &null;
+		continue;
+	
+	__DATE:
+	__VARIANT:
+	__VOID:
+	__ARRAY:
+	__CLASS:
+	__FUNCTION:
+	
+		ERROR_panic("Bad type (%d) for EXTERN_call", value->type);
   }
   
+  rtype = _to_ffi_type[ext->type];
+  
   func = get_function(ext);
   
+	if (ffi_prep_cif(&cif, FFI_DEFAULT_ABI, nparam,	rtype, types) != FFI_OK)
+		ERROR_panic("ffi_prep_cif has failed");
+  
+	ffi_call(&cif, func, rvalue, args);
+
   switch (ext->type)
   {
     case T_BOOLEAN:
     case T_BYTE:
     case T_SHORT:
     case T_INTEGER:
-      GB_ReturnInteger(CAST(int, func)(args));
+      GB_ReturnInteger(*(int *)POINTER(rvalue));
       break;
     
     case T_LONG:
-      GB_ReturnLong(CAST(long long, func)(args));
+      GB_ReturnLong(*(int64_t *)POINTER(rvalue));
       break;
     
     case T_SINGLE:
-      GB_ReturnFloat(CAST(float, func)(args));
+      GB_ReturnFloat(*(float *)POINTER(rvalue));
       break;
       
     case T_FLOAT:
-      GB_ReturnFloat(CAST(double, func)(args));
+      GB_ReturnFloat(*(double *)POINTER(rvalue));
       break;
       
     case T_STRING:
-      GB_ReturnConstString(CAST(char *, func)(args), 0);
+      GB_ReturnConstString(*(char **)POINTER(rvalue), 0);
       break;
     
     default:
-      CAST(void, func)(args);
-      GB_ReturnNull();
+      //GB_ReturnNull();
       break;
-  }
-  
+  }	
+
   while (nparam > 0)
   {
     nparam--;
@@ -301,9 +385,14 @@ PUBLIC void EXTERN_call(void)
     SP++;
   }
 }
+#else
+void EXTERN_call(void)
+{
+	THROW(E_ILLEGAL);
+}
+#endif
 
-
-PUBLIC void EXTERN_exit(void)
+void EXTERN_exit(void)
 {
   int i;
   EXTERN_SYMBOL *esym;
