@@ -404,7 +404,7 @@ static void make_query_get_param(int index, char **str, int *len)
 static char *make_query(CCONNECTION *_object, char *pattern, int len, int narg, GB_VALUE *arg)
 {
 	char *query;
-	char *keyword;
+	const char *keyword;
 	char buffer[32];
 
 	query = DB_MakeQuery(THIS->driver, pattern, len, narg, arg);
@@ -415,7 +415,7 @@ static char *make_query(CCONNECTION *_object, char *pattern, int len, int narg,
 		if (!keyword)
 			keyword = "LIMIT";
 
-		sprintf(buffer, "%s %d", keyword, THIS->limit);
+		snprintf(buffer, sizeof(buffer), "%s %d", keyword, THIS->limit);
 
 		_make_query_buffer = buffer;
 		_make_query_original = &query[7];
