@@ -33,7 +33,6 @@
 #include "eval.h"
 #include "eval_read.h"
 
-
 //#define DEBUG 1
 
 PUBLIC const char *READ_source_ptr;
@@ -120,7 +119,10 @@ PUBLIC char *READ_get_pattern(PATTERN *pattern)
 
     case RT_STRING:
     case RT_TSTRING:
-      snprintf(_buffer, BUF_MAX, "\"%s\"", TABLE_get_symbol_name(EVAL->string, index));
+    	if (_no_quote)
+	      snprintf(_buffer, BUF_MAX, "\"%s\"", TABLE_get_symbol_name(EVAL->string, index));
+      else
+      	strcpy(_buffer, "string");
       break;
 
     case RT_NEWLINE:
@@ -134,7 +136,7 @@ PUBLIC char *READ_get_pattern(PATTERN *pattern)
       break;
 
     default:
-      sprintf(_buffer, "%s?%p?%s", before, (void *)*pattern, after);
+      sprintf(_buffer, "%s?%08X?%s", before, *pattern, after);
   }
 
   return _buffer;
